/* Generated file (by generator) */

/*
 * SPDX-FileCopyrightText: 2015 William Yu <williamyu@gnome.org>
 *
 * SPDX-License-Identifier: LGPL-2.1-only OR MPL-2.0
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "i-cal-derived-property.h"
#include "libical-glib-private.h"
#include "i-cal-property.h"
#include "i-cal-datetimeperiod.h"
#include "i-cal-attach.h"
#include "i-cal-recurrence.h"
#include "i-cal-reqstat.h"
#include "i-cal-trigger.h"
#include "i-cal-period.h"
#include "i-cal-geo.h"
#include "i-cal-time.h"
#include "i-cal-derived-value.h"
#include "i-cal-duration.h"

/**
 * i_cal_property_new_acceptresponse:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding ACCEPTRESPONSE.
 *
 * Returns: (transfer full): a new #ICalProperty holding ACCEPTRESPONSE
 *
 * Since: 2.0
 *
 **/
ICalProperty *
i_cal_property_new_acceptresponse (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_acceptresponse (value), NULL);
}

/**
 * i_cal_property_get_acceptresponse:
 * @self: the #ICalProperty of ACCEPTRESPONSE
 *
 * Returns value of the ACCEPTRESPONSE @self
 *
 * Returns: the ACCEPTRESPONSE value
 *
 * Since: 2.0
 *
 **/
const gchar *
i_cal_property_get_acceptresponse (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_acceptresponse ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_acceptresponse:
 * @self: the #ICalProperty of ACCEPTRESPONSE
 * @value: the ACCEPTRESPONSE value
 *
 * Sets value to the ACCEPTRESPONSE @self
 *
 * Since: 2.0
 *
 **/
void
i_cal_property_set_acceptresponse (ICalProperty *self, 
                                   const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_acceptresponse ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_acknowledged:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding ACKNOWLEDGED.
 *
 * Returns: (transfer full): a new #ICalProperty holding ACKNOWLEDGED
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_acknowledged (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_acknowledged (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_acknowledged:
 * @self: the #ICalProperty of ACKNOWLEDGED
 *
 * Returns value of the ACKNOWLEDGED @self
 *
 * Returns: (transfer full): the ACKNOWLEDGED value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_acknowledged (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_acknowledged ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_acknowledged:
 * @self: the #ICalProperty of ACKNOWLEDGED
 * @value: the ACKNOWLEDGED value
 *
 * Sets value to the ACKNOWLEDGED @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_acknowledged (ICalProperty *self, 
                                 const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_acknowledged ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_action:
 * @value: the #ICalPropertyAction value
 *
 * Creates a new #ICalProperty holding ACTION.
 *
 * Returns: (transfer full): a new #ICalProperty holding ACTION
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_action (ICalPropertyAction value)
{
	return i_cal_property_new_full (icalproperty_new_action ((icalproperty_action) (value)), NULL);
}

/**
 * i_cal_property_get_action:
 * @self: the #ICalProperty of ACTION
 *
 * Returns value of the ACTION @self
 *
 * Returns: the ACTION value
 *
 * Since: 1.0
 *
 **/
ICalPropertyAction
i_cal_property_get_action (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_ACTION_NONE);

	return (ICalPropertyAction) (icalproperty_get_action ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_action:
 * @self: the #ICalProperty of ACTION
 * @value: the ACTION value
 *
 * Sets value to the ACTION @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_action (ICalProperty *self, 
                           ICalPropertyAction value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_action ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_action) (value));
}

/**
 * i_cal_property_new_allowconflict:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding ALLOWCONFLICT.
 *
 * Returns: (transfer full): a new #ICalProperty holding ALLOWCONFLICT
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_allowconflict (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_allowconflict (value), NULL);
}

/**
 * i_cal_property_get_allowconflict:
 * @self: the #ICalProperty of ALLOWCONFLICT
 *
 * Returns value of the ALLOWCONFLICT @self
 *
 * Returns: the ALLOWCONFLICT value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_allowconflict (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_allowconflict ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_allowconflict:
 * @self: the #ICalProperty of ALLOWCONFLICT
 * @value: the ALLOWCONFLICT value
 *
 * Sets value to the ALLOWCONFLICT @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_allowconflict (ICalProperty *self, 
                                  const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_allowconflict ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_attach:
 * @value: the #ICalAttach value
 *
 * Creates a new #ICalProperty holding ATTACH.
 *
 * Returns: (transfer full): a new #ICalProperty holding ATTACH
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_attach (const ICalAttach *value)
{
    g_return_val_if_fail (I_CAL_IS_ATTACH ((ICalAttach*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_attach ((icalattach *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_attach:
 * @self: the #ICalProperty of ATTACH
 *
 * Returns value of the ATTACH @self
 *
 * Returns: (transfer full): the ATTACH value
 *
 * Since: 1.0
 *
 **/
ICalAttach *
i_cal_property_get_attach (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_attach_new_full (icalproperty_get_attach ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))), (GObject *)self);
}

/**
 * i_cal_property_set_attach:
 * @self: the #ICalProperty of ATTACH
 * @value: the ATTACH value
 *
 * Sets value to the ATTACH @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_attach (ICalProperty *self, 
                           const ICalAttach *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_ATTACH ((ICalAttach*)value));

	icalproperty_set_attach ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalattach *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_attendee:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding ATTENDEE.
 *
 * Returns: (transfer full): a new #ICalProperty holding ATTENDEE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_attendee (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_attendee (value), NULL);
}

/**
 * i_cal_property_get_attendee:
 * @self: the #ICalProperty of ATTENDEE
 *
 * Returns value of the ATTENDEE @self
 *
 * Returns: the ATTENDEE value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_attendee (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_attendee ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_attendee:
 * @self: the #ICalProperty of ATTENDEE
 * @value: the ATTENDEE value
 *
 * Sets value to the ATTENDEE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_attendee (ICalProperty *self, 
                             const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_attendee ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_busytype:
 * @value: the #ICalPropertyBusytype value
 *
 * Creates a new #ICalProperty holding BUSYTYPE.
 *
 * Returns: (transfer full): a new #ICalProperty holding BUSYTYPE
 *
 * Since: 2.0
 *
 **/
ICalProperty *
i_cal_property_new_busytype (ICalPropertyBusytype value)
{
	return i_cal_property_new_full (icalproperty_new_busytype ((icalproperty_busytype) (value)), NULL);
}

/**
 * i_cal_property_get_busytype:
 * @self: the #ICalProperty of BUSYTYPE
 *
 * Returns value of the BUSYTYPE @self
 *
 * Returns: the BUSYTYPE value
 *
 * Since: 2.0
 *
 **/
ICalPropertyBusytype
i_cal_property_get_busytype (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_BUSYTYPE_NONE);

	return (ICalPropertyBusytype) (icalproperty_get_busytype ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_busytype:
 * @self: the #ICalProperty of BUSYTYPE
 * @value: the BUSYTYPE value
 *
 * Sets value to the BUSYTYPE @self
 *
 * Since: 2.0
 *
 **/
void
i_cal_property_set_busytype (ICalProperty *self, 
                             ICalPropertyBusytype value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_busytype ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_busytype) (value));
}

/**
 * i_cal_property_new_calendaraddress:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding CALENDARADDRESS.
 *
 * Returns: (transfer full): a new #ICalProperty holding CALENDARADDRESS
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_calendaraddress (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_calendaraddress (value), NULL);
}

/**
 * i_cal_property_get_calendaraddress:
 * @self: the #ICalProperty of CALENDARADDRESS
 *
 * Returns value of the CALENDARADDRESS @self
 *
 * Returns: the CALENDARADDRESS value
 *
 * Since: 4.0
 *
 **/
const gchar *
i_cal_property_get_calendaraddress (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_calendaraddress ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_calendaraddress:
 * @self: the #ICalProperty of CALENDARADDRESS
 * @value: the CALENDARADDRESS value
 *
 * Sets value to the CALENDARADDRESS @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_calendaraddress (ICalProperty *self, 
                                    const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_calendaraddress ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_calid:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding CALID.
 *
 * Returns: (transfer full): a new #ICalProperty holding CALID
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_calid (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_calid (value), NULL);
}

/**
 * i_cal_property_get_calid:
 * @self: the #ICalProperty of CALID
 *
 * Returns value of the CALID @self
 *
 * Returns: the CALID value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_calid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_calid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_calid:
 * @self: the #ICalProperty of CALID
 * @value: the CALID value
 *
 * Sets value to the CALID @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_calid (ICalProperty *self, 
                          const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_calid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_calmaster:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding CALMASTER.
 *
 * Returns: (transfer full): a new #ICalProperty holding CALMASTER
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_calmaster (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_calmaster (value), NULL);
}

/**
 * i_cal_property_get_calmaster:
 * @self: the #ICalProperty of CALMASTER
 *
 * Returns value of the CALMASTER @self
 *
 * Returns: the CALMASTER value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_calmaster (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_calmaster ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_calmaster:
 * @self: the #ICalProperty of CALMASTER
 * @value: the CALMASTER value
 *
 * Sets value to the CALMASTER @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_calmaster (ICalProperty *self, 
                              const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_calmaster ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_calscale:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding CALSCALE.
 *
 * Returns: (transfer full): a new #ICalProperty holding CALSCALE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_calscale (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_calscale (value), NULL);
}

/**
 * i_cal_property_get_calscale:
 * @self: the #ICalProperty of CALSCALE
 *
 * Returns value of the CALSCALE @self
 *
 * Returns: the CALSCALE value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_calscale (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_calscale ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_calscale:
 * @self: the #ICalProperty of CALSCALE
 * @value: the CALSCALE value
 *
 * Sets value to the CALSCALE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_calscale (ICalProperty *self, 
                             const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_calscale ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_capversion:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding CAPVERSION.
 *
 * Returns: (transfer full): a new #ICalProperty holding CAPVERSION
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_capversion (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_capversion (value), NULL);
}

/**
 * i_cal_property_get_capversion:
 * @self: the #ICalProperty of CAPVERSION
 *
 * Returns value of the CAPVERSION @self
 *
 * Returns: the CAPVERSION value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_capversion (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_capversion ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_capversion:
 * @self: the #ICalProperty of CAPVERSION
 * @value: the CAPVERSION value
 *
 * Sets value to the CAPVERSION @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_capversion (ICalProperty *self, 
                               const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_capversion ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_carlevel:
 * @value: the #ICalPropertyCarlevel value
 *
 * Creates a new #ICalProperty holding CARLEVEL.
 *
 * Returns: (transfer full): a new #ICalProperty holding CARLEVEL
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_carlevel (ICalPropertyCarlevel value)
{
	return i_cal_property_new_full (icalproperty_new_carlevel ((icalproperty_carlevel) (value)), NULL);
}

/**
 * i_cal_property_get_carlevel:
 * @self: the #ICalProperty of CARLEVEL
 *
 * Returns value of the CARLEVEL @self
 *
 * Returns: the CARLEVEL value
 *
 * Since: 1.0
 *
 **/
ICalPropertyCarlevel
i_cal_property_get_carlevel (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_CARLEVEL_NONE);

	return (ICalPropertyCarlevel) (icalproperty_get_carlevel ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_carlevel:
 * @self: the #ICalProperty of CARLEVEL
 * @value: the CARLEVEL value
 *
 * Sets value to the CARLEVEL @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_carlevel (ICalProperty *self, 
                             ICalPropertyCarlevel value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_carlevel ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_carlevel) (value));
}

/**
 * i_cal_property_new_carid:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding CARID.
 *
 * Returns: (transfer full): a new #ICalProperty holding CARID
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_carid (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_carid (value), NULL);
}

/**
 * i_cal_property_get_carid:
 * @self: the #ICalProperty of CARID
 *
 * Returns value of the CARID @self
 *
 * Returns: the CARID value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_carid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_carid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_carid:
 * @self: the #ICalProperty of CARID
 * @value: the CARID value
 *
 * Sets value to the CARID @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_carid (ICalProperty *self, 
                          const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_carid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_categories:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding CATEGORIES.
 *
 * Returns: (transfer full): a new #ICalProperty holding CATEGORIES
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_categories (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_categories (value), NULL);
}

/**
 * i_cal_property_get_categories:
 * @self: the #ICalProperty of CATEGORIES
 *
 * Returns value of the CATEGORIES @self
 *
 * Returns: the CATEGORIES value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_categories (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_categories ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_categories:
 * @self: the #ICalProperty of CATEGORIES
 * @value: the CATEGORIES value
 *
 * Sets value to the CATEGORIES @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_categories (ICalProperty *self, 
                               const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_categories ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_class:
 * @value: the #ICalPropertyClassenum value
 *
 * Creates a new #ICalProperty holding CLASS.
 *
 * Returns: (transfer full): a new #ICalProperty holding CLASS
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_class (ICalPropertyClassenum value)
{
	return i_cal_property_new_full (icalproperty_new_class ((icalproperty_class) (value)), NULL);
}

/**
 * i_cal_property_get_class:
 * @self: the #ICalProperty of CLASS
 *
 * Returns value of the CLASS @self
 *
 * Returns: the CLASS value
 *
 * Since: 1.0
 *
 **/
ICalPropertyClassenum
i_cal_property_get_class (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_CLASS_NONE);

	return (ICalPropertyClassenum) (icalproperty_get_class ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_class:
 * @self: the #ICalProperty of CLASS
 * @value: the CLASS value
 *
 * Sets value to the CLASS @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_class (ICalProperty *self, 
                          ICalPropertyClassenum value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_class ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_class) (value));
}

/**
 * i_cal_property_new_cmd:
 * @value: the #ICalPropertyCmd value
 *
 * Creates a new #ICalProperty holding CMD.
 *
 * Returns: (transfer full): a new #ICalProperty holding CMD
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_cmd (ICalPropertyCmd value)
{
	return i_cal_property_new_full (icalproperty_new_cmd ((icalproperty_cmd) (value)), NULL);
}

/**
 * i_cal_property_get_cmd:
 * @self: the #ICalProperty of CMD
 *
 * Returns value of the CMD @self
 *
 * Returns: the CMD value
 *
 * Since: 1.0
 *
 **/
ICalPropertyCmd
i_cal_property_get_cmd (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_CMD_NONE);

	return (ICalPropertyCmd) (icalproperty_get_cmd ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_cmd:
 * @self: the #ICalProperty of CMD
 * @value: the CMD value
 *
 * Sets value to the CMD @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_cmd (ICalProperty *self, 
                        ICalPropertyCmd value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_cmd ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_cmd) (value));
}

/**
 * i_cal_property_new_comment:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding COMMENT.
 *
 * Returns: (transfer full): a new #ICalProperty holding COMMENT
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_comment (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_comment (value), NULL);
}

/**
 * i_cal_property_get_comment:
 * @self: the #ICalProperty of COMMENT
 *
 * Returns value of the COMMENT @self
 *
 * Returns: the COMMENT value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_comment (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_comment ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_comment:
 * @self: the #ICalProperty of COMMENT
 * @value: the COMMENT value
 *
 * Sets value to the COMMENT @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_comment (ICalProperty *self, 
                            const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_comment ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_color:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding COLOR.
 *
 * Returns: (transfer full): a new #ICalProperty holding COLOR
 *
 * Since: 3.0.5
 *
 **/
ICalProperty *
i_cal_property_new_color (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_color (value), NULL);
}

/**
 * i_cal_property_get_color:
 * @self: the #ICalProperty of COLOR
 *
 * Returns value of the COLOR @self
 *
 * Returns: the COLOR value
 *
 * Since: 3.0.5
 *
 **/
const gchar *
i_cal_property_get_color (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_color ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_color:
 * @self: the #ICalProperty of COLOR
 * @value: the COLOR value
 *
 * Sets value to the COLOR @self
 *
 * Since: 3.0.5
 *
 **/
void
i_cal_property_set_color (ICalProperty *self, 
                          const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_color ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_completed:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding COMPLETED.
 *
 * Returns: (transfer full): a new #ICalProperty holding COMPLETED
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_completed (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_completed (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_completed:
 * @self: the #ICalProperty of COMPLETED
 *
 * Returns value of the COMPLETED @self
 *
 * Returns: (transfer full): the COMPLETED value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_completed (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_completed ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_completed:
 * @self: the #ICalProperty of COMPLETED
 * @value: the COMPLETED value
 *
 * Sets value to the COMPLETED @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_completed (ICalProperty *self, 
                              const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_completed ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_components:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding COMPONENTS.
 *
 * Returns: (transfer full): a new #ICalProperty holding COMPONENTS
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_components (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_components (value), NULL);
}

/**
 * i_cal_property_get_components:
 * @self: the #ICalProperty of COMPONENTS
 *
 * Returns value of the COMPONENTS @self
 *
 * Returns: the COMPONENTS value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_components (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_components ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_components:
 * @self: the #ICalProperty of COMPONENTS
 * @value: the COMPONENTS value
 *
 * Sets value to the COMPONENTS @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_components (ICalProperty *self, 
                               const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_components ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_concept:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding CONCEPT.
 *
 * Returns: (transfer full): a new #ICalProperty holding CONCEPT
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_concept (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_concept (value), NULL);
}

/**
 * i_cal_property_get_concept:
 * @self: the #ICalProperty of CONCEPT
 *
 * Returns value of the CONCEPT @self
 *
 * Returns: the CONCEPT value
 *
 * Since: 4.0
 *
 **/
const gchar *
i_cal_property_get_concept (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_concept ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_concept:
 * @self: the #ICalProperty of CONCEPT
 * @value: the CONCEPT value
 *
 * Sets value to the CONCEPT @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_concept (ICalProperty *self, 
                            const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_concept ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_conference:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding CONFERENCE.
 *
 * Returns: (transfer full): a new #ICalProperty holding CONFERENCE
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_conference (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_conference (value), NULL);
}

/**
 * i_cal_property_get_conference:
 * @self: the #ICalProperty of CONFERENCE
 *
 * Returns value of the CONFERENCE @self
 *
 * Returns: the CONFERENCE value
 *
 * Since: 4.0
 *
 **/
const gchar *
i_cal_property_get_conference (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_conference ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_conference:
 * @self: the #ICalProperty of CONFERENCE
 * @value: the CONFERENCE value
 *
 * Sets value to the CONFERENCE @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_conference (ICalProperty *self, 
                               const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_conference ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_contact:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding CONTACT.
 *
 * Returns: (transfer full): a new #ICalProperty holding CONTACT
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_contact (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_contact (value), NULL);
}

/**
 * i_cal_property_get_contact:
 * @self: the #ICalProperty of CONTACT
 *
 * Returns value of the CONTACT @self
 *
 * Returns: the CONTACT value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_contact (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_contact ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_contact:
 * @self: the #ICalProperty of CONTACT
 * @value: the CONTACT value
 *
 * Sets value to the CONTACT @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_contact (ICalProperty *self, 
                            const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_contact ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_created:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding CREATED.
 *
 * Returns: (transfer full): a new #ICalProperty holding CREATED
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_created (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_created (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_created:
 * @self: the #ICalProperty of CREATED
 *
 * Returns value of the CREATED @self
 *
 * Returns: (transfer full): the CREATED value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_created (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_created ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_created:
 * @self: the #ICalProperty of CREATED
 * @value: the CREATED value
 *
 * Sets value to the CREATED @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_created (ICalProperty *self, 
                            const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_created ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_csid:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding CSID.
 *
 * Returns: (transfer full): a new #ICalProperty holding CSID
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_csid (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_csid (value), NULL);
}

/**
 * i_cal_property_get_csid:
 * @self: the #ICalProperty of CSID
 *
 * Returns value of the CSID @self
 *
 * Returns: the CSID value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_csid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_csid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_csid:
 * @self: the #ICalProperty of CSID
 * @value: the CSID value
 *
 * Sets value to the CSID @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_csid (ICalProperty *self, 
                         const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_csid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_datemax:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding DATEMAX.
 *
 * Returns: (transfer full): a new #ICalProperty holding DATEMAX
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_datemax (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_datemax (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_datemax:
 * @self: the #ICalProperty of DATEMAX
 *
 * Returns value of the DATEMAX @self
 *
 * Returns: (transfer full): the DATEMAX value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_datemax (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_datemax ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_datemax:
 * @self: the #ICalProperty of DATEMAX
 * @value: the DATEMAX value
 *
 * Sets value to the DATEMAX @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_datemax (ICalProperty *self, 
                            const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_datemax ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_datemin:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding DATEMIN.
 *
 * Returns: (transfer full): a new #ICalProperty holding DATEMIN
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_datemin (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_datemin (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_datemin:
 * @self: the #ICalProperty of DATEMIN
 *
 * Returns value of the DATEMIN @self
 *
 * Returns: (transfer full): the DATEMIN value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_datemin (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_datemin ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_datemin:
 * @self: the #ICalProperty of DATEMIN
 * @value: the DATEMIN value
 *
 * Sets value to the DATEMIN @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_datemin (ICalProperty *self, 
                            const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_datemin ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_decreed:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding DECREED.
 *
 * Returns: (transfer full): a new #ICalProperty holding DECREED
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_decreed (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_decreed (value), NULL);
}

/**
 * i_cal_property_get_decreed:
 * @self: the #ICalProperty of DECREED
 *
 * Returns value of the DECREED @self
 *
 * Returns: the DECREED value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_decreed (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_decreed ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_decreed:
 * @self: the #ICalProperty of DECREED
 * @value: the DECREED value
 *
 * Sets value to the DECREED @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_decreed (ICalProperty *self, 
                            const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_decreed ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_defaultcharset:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding DEFAULTCHARSET.
 *
 * Returns: (transfer full): a new #ICalProperty holding DEFAULTCHARSET
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_defaultcharset (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_defaultcharset (value), NULL);
}

/**
 * i_cal_property_get_defaultcharset:
 * @self: the #ICalProperty of DEFAULTCHARSET
 *
 * Returns value of the DEFAULTCHARSET @self
 *
 * Returns: the DEFAULTCHARSET value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_defaultcharset (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_defaultcharset ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_defaultcharset:
 * @self: the #ICalProperty of DEFAULTCHARSET
 * @value: the DEFAULTCHARSET value
 *
 * Sets value to the DEFAULTCHARSET @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_defaultcharset (ICalProperty *self, 
                                   const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_defaultcharset ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_defaultlocale:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding DEFAULTLOCALE.
 *
 * Returns: (transfer full): a new #ICalProperty holding DEFAULTLOCALE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_defaultlocale (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_defaultlocale (value), NULL);
}

/**
 * i_cal_property_get_defaultlocale:
 * @self: the #ICalProperty of DEFAULTLOCALE
 *
 * Returns value of the DEFAULTLOCALE @self
 *
 * Returns: the DEFAULTLOCALE value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_defaultlocale (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_defaultlocale ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_defaultlocale:
 * @self: the #ICalProperty of DEFAULTLOCALE
 * @value: the DEFAULTLOCALE value
 *
 * Sets value to the DEFAULTLOCALE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_defaultlocale (ICalProperty *self, 
                                  const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_defaultlocale ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_defaulttzid:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding DEFAULTTZID.
 *
 * Returns: (transfer full): a new #ICalProperty holding DEFAULTTZID
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_defaulttzid (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_defaulttzid (value), NULL);
}

/**
 * i_cal_property_get_defaulttzid:
 * @self: the #ICalProperty of DEFAULTTZID
 *
 * Returns value of the DEFAULTTZID @self
 *
 * Returns: the DEFAULTTZID value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_defaulttzid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_defaulttzid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_defaulttzid:
 * @self: the #ICalProperty of DEFAULTTZID
 * @value: the DEFAULTTZID value
 *
 * Sets value to the DEFAULTTZID @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_defaulttzid (ICalProperty *self, 
                                const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_defaulttzid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_defaultvcars:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding DEFAULTVCARS.
 *
 * Returns: (transfer full): a new #ICalProperty holding DEFAULTVCARS
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_defaultvcars (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_defaultvcars (value), NULL);
}

/**
 * i_cal_property_get_defaultvcars:
 * @self: the #ICalProperty of DEFAULTVCARS
 *
 * Returns value of the DEFAULTVCARS @self
 *
 * Returns: the DEFAULTVCARS value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_defaultvcars (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_defaultvcars ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_defaultvcars:
 * @self: the #ICalProperty of DEFAULTVCARS
 * @value: the DEFAULTVCARS value
 *
 * Sets value to the DEFAULTVCARS @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_defaultvcars (ICalProperty *self, 
                                 const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_defaultvcars ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_deny:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding deny.
 *
 * Returns: (transfer full): a new #ICalProperty holding deny
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_deny (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_deny (value), NULL);
}

/**
 * i_cal_property_get_deny:
 * @self: the #ICalProperty of deny
 *
 * Returns value of the deny @self
 *
 * Returns: the deny value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_deny (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_deny ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_deny:
 * @self: the #ICalProperty of deny
 * @value: the deny value
 *
 * Sets value to the deny @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_deny (ICalProperty *self, 
                         const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_deny ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_description:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding description.
 *
 * Returns: (transfer full): a new #ICalProperty holding description
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_description (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_description (value), NULL);
}

/**
 * i_cal_property_get_description:
 * @self: the #ICalProperty of description
 *
 * Returns value of the description @self
 *
 * Returns: the description value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_description (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_description ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_description:
 * @self: the #ICalProperty of description
 * @value: the description value
 *
 * Sets value to the description @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_description (ICalProperty *self, 
                                const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_description ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_dtend:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding DTEND.
 *
 * Returns: (transfer full): a new #ICalProperty holding DTEND
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_dtend (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_dtend (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_dtend:
 * @self: the #ICalProperty of DTEND
 *
 * Returns value of the DTEND @self
 *
 * Returns: (transfer full): the DTEND value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_dtend (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_dtend ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_dtend:
 * @self: the #ICalProperty of DTEND
 * @value: the DTEND value
 *
 * Sets value to the DTEND @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_dtend (ICalProperty *self, 
                          const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_dtend ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_dtstamp:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding DTSTAMP.
 *
 * Returns: (transfer full): a new #ICalProperty holding DTSTAMP
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_dtstamp (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_dtstamp (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_dtstamp:
 * @self: the #ICalProperty of DTSTAMP
 *
 * Returns value of the DTSTAMP @self
 *
 * Returns: (transfer full): the DTSTAMP value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_dtstamp (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_dtstamp ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_dtstamp:
 * @self: the #ICalProperty of DTSTAMP
 * @value: the DTSTAMP value
 *
 * Sets value to the DTSTAMP @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_dtstamp (ICalProperty *self, 
                            const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_dtstamp ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_dtstart:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding DTSTART.
 *
 * Returns: (transfer full): a new #ICalProperty holding DTSTART
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_dtstart (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_dtstart (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_dtstart:
 * @self: the #ICalProperty of DTSTART
 *
 * Returns value of the DTSTART @self
 *
 * Returns: (transfer full): the DTSTART value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_dtstart (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_dtstart ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_dtstart:
 * @self: the #ICalProperty of DTSTART
 * @value: the DTSTART value
 *
 * Sets value to the DTSTART @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_dtstart (ICalProperty *self, 
                            const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_dtstart ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_due:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding DUE.
 *
 * Returns: (transfer full): a new #ICalProperty holding DUE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_due (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_due (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_due:
 * @self: the #ICalProperty of DUE
 *
 * Returns value of the DUE @self
 *
 * Returns: (transfer full): the DUE value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_due (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_due ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_due:
 * @self: the #ICalProperty of DUE
 * @value: the DUE value
 *
 * Sets value to the DUE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_due (ICalProperty *self, 
                        const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_due ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_duration:
 * @value: the #ICalDuration value
 *
 * Creates a new #ICalProperty holding DURATION.
 *
 * Returns: (transfer full): a new #ICalProperty holding DURATION
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_duration (const ICalDuration *value)
{
    g_return_val_if_fail (I_CAL_IS_DURATION ((ICalDuration*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_duration (* (struct icaldurationtype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_duration:
 * @self: the #ICalProperty of DURATION
 *
 * Returns value of the DURATION @self
 *
 * Returns: (transfer full): the DURATION value
 *
 * Since: 1.0
 *
 **/
ICalDuration *
i_cal_property_get_duration (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_duration_new_full (icalproperty_get_duration ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_duration:
 * @self: the #ICalProperty of DURATION
 * @value: the DURATION value
 *
 * Sets value to the DURATION @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_duration (ICalProperty *self, 
                             const ICalDuration *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_DURATION ((ICalDuration*)value));

	icalproperty_set_duration ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaldurationtype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_estimatedduration:
 * @value: the #ICalDuration value
 *
 * Creates a new #ICalProperty holding ESTIMATEDDURATION.
 *
 * Returns: (transfer full): a new #ICalProperty holding ESTIMATEDDURATION
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_estimatedduration (const ICalDuration *value)
{
    g_return_val_if_fail (I_CAL_IS_DURATION ((ICalDuration*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_estimatedduration (* (struct icaldurationtype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_estimatedduration:
 * @self: the #ICalProperty of ESTIMATEDDURATION
 *
 * Returns value of the ESTIMATEDDURATION @self
 *
 * Returns: (transfer full): the ESTIMATEDDURATION value
 *
 * Since: 1.0
 *
 **/
ICalDuration *
i_cal_property_get_estimatedduration (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_duration_new_full (icalproperty_get_estimatedduration ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_estimatedduration:
 * @self: the #ICalProperty of ESTIMATEDDURATION
 * @value: the ESTIMATEDDURATION value
 *
 * Sets value to the ESTIMATEDDURATION @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_estimatedduration (ICalProperty *self, 
                                      const ICalDuration *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_DURATION ((ICalDuration*)value));

	icalproperty_set_estimatedduration ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaldurationtype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_exdate:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding EXDATE.
 *
 * Returns: (transfer full): a new #ICalProperty holding EXDATE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_exdate (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_exdate (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_exdate:
 * @self: the #ICalProperty of EXDATE
 *
 * Returns value of the EXDATE @self
 *
 * Returns: (transfer full): the EXDATE value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_exdate (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_exdate ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_exdate:
 * @self: the #ICalProperty of EXDATE
 * @value: the EXDATE value
 *
 * Sets value to the EXDATE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_exdate (ICalProperty *self, 
                           const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_exdate ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_expand:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding EXPAND.
 *
 * Returns: (transfer full): a new #ICalProperty holding EXPAND
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_expand (gint value)
{
	return i_cal_property_new_full (icalproperty_new_expand (value), NULL);
}

/**
 * i_cal_property_get_expand:
 * @self: the #ICalProperty of EXPAND
 *
 * Returns value of the EXPAND @self
 *
 * Returns: the EXPAND value
 *
 * Since: 1.0
 *
 **/
gint
i_cal_property_get_expand (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_expand ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_expand:
 * @self: the #ICalProperty of EXPAND
 * @value: the EXPAND value
 *
 * Sets value to the EXPAND @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_expand (ICalProperty *self, 
                           gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_expand ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_exrule:
 * @value: the #ICalRecurrence value
 *
 * Creates a new #ICalProperty holding EXRULE.
 *
 * Returns: (transfer full): a new #ICalProperty holding EXRULE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_exrule (const ICalRecurrence *value)
{
    g_return_val_if_fail (I_CAL_IS_RECURRENCE ((ICalRecurrence*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_exrule ((struct icalrecurrencetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_exrule:
 * @self: the #ICalProperty of EXRULE
 *
 * Returns value of the EXRULE @self
 *
 * Returns: (transfer full): the EXRULE value
 *
 * Since: 1.0
 *
 **/
ICalRecurrence *
i_cal_property_get_exrule (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_recurrence_new_full (icalproperty_get_exrule ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))), (GObject *)self);
}

/**
 * i_cal_property_set_exrule:
 * @self: the #ICalProperty of EXRULE
 * @value: the EXRULE value
 *
 * Sets value to the EXRULE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_exrule (ICalProperty *self, 
                           const ICalRecurrence *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_RECURRENCE ((ICalRecurrence*)value));

	icalproperty_set_exrule ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (struct icalrecurrencetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_freebusy:
 * @value: the #ICalPeriod value
 *
 * Creates a new #ICalProperty holding FREEBUSY.
 *
 * Returns: (transfer full): a new #ICalProperty holding FREEBUSY
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_freebusy (const ICalPeriod *value)
{
    g_return_val_if_fail (I_CAL_IS_PERIOD ((ICalPeriod*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_freebusy (* (struct icalperiodtype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_freebusy:
 * @self: the #ICalProperty of FREEBUSY
 *
 * Returns value of the FREEBUSY @self
 *
 * Returns: (transfer full): the FREEBUSY value
 *
 * Since: 1.0
 *
 **/
ICalPeriod *
i_cal_property_get_freebusy (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_period_new_full (icalproperty_get_freebusy ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_freebusy:
 * @self: the #ICalProperty of FREEBUSY
 * @value: the FREEBUSY value
 *
 * Sets value to the FREEBUSY @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_freebusy (ICalProperty *self, 
                             const ICalPeriod *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_PERIOD ((ICalPeriod*)value));

	icalproperty_set_freebusy ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icalperiodtype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_geo:
 * @value: the #ICalGeo value
 *
 * Creates a new #ICalProperty holding GEO.
 *
 * Returns: (transfer full): a new #ICalProperty holding GEO
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_geo (const ICalGeo *value)
{
    g_return_val_if_fail (I_CAL_IS_GEO ((ICalGeo*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_geo (* (struct icalgeotype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_geo:
 * @self: the #ICalProperty of GEO
 *
 * Returns value of the GEO @self
 *
 * Returns: (transfer full): the GEO value
 *
 * Since: 1.0
 *
 **/
ICalGeo *
i_cal_property_get_geo (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_geo_new_full (icalproperty_get_geo ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_geo:
 * @self: the #ICalProperty of GEO
 * @value: the GEO value
 *
 * Sets value to the GEO @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_geo (ICalProperty *self, 
                        const ICalGeo *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_GEO ((ICalGeo*)value));

	icalproperty_set_geo ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icalgeotype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_grant:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding GRANT.
 *
 * Returns: (transfer full): a new #ICalProperty holding GRANT
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_grant (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_grant (value), NULL);
}

/**
 * i_cal_property_get_grant:
 * @self: the #ICalProperty of GRANT
 *
 * Returns value of the GRANT @self
 *
 * Returns: the GRANT value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_grant (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_grant ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_grant:
 * @self: the #ICalProperty of GRANT
 * @value: the GRANT value
 *
 * Sets value to the GRANT @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_grant (ICalProperty *self, 
                          const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_grant ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_iana:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding IANA.
 *
 * Returns: (transfer full): a new #ICalProperty holding IANA
 *
 * Since: 3.1
 *
 **/
ICalProperty *
i_cal_property_new_iana (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_iana (value), NULL);
}

/**
 * i_cal_property_get_iana:
 * @self: the #ICalProperty of IANA
 *
 * Returns value of the IANA @self
 *
 * Returns: the IANA value
 *
 * Since: 3.1
 *
 **/
const gchar *
i_cal_property_get_iana (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_iana ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_iana:
 * @self: the #ICalProperty of IANA
 * @value: the IANA value
 *
 * Sets value to the IANA @self
 *
 * Since: 3.1
 *
 **/
void
i_cal_property_set_iana (ICalProperty *self, 
                         const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_iana ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_image:
 * @value: the #ICalAttach value
 *
 * Creates a new #ICalProperty holding IMAGE.
 *
 * Returns: (transfer full): a new #ICalProperty holding IMAGE
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_image (const ICalAttach *value)
{
    g_return_val_if_fail (I_CAL_IS_ATTACH ((ICalAttach*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_image ((icalattach *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_image:
 * @self: the #ICalProperty of IMAGE
 *
 * Returns value of the IMAGE @self
 *
 * Returns: (transfer full): the IMAGE value
 *
 * Since: 4.0
 *
 **/
ICalAttach *
i_cal_property_get_image (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_attach_new_full (icalproperty_get_image ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))), (GObject *)self);
}

/**
 * i_cal_property_set_image:
 * @self: the #ICalProperty of IMAGE
 * @value: the IMAGE value
 *
 * Sets value to the IMAGE @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_image (ICalProperty *self, 
                          const ICalAttach *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_ATTACH ((ICalAttach*)value));

	icalproperty_set_image ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalattach *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_itipversion:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding ITIPVERSION.
 *
 * Returns: (transfer full): a new #ICalProperty holding ITIPVERSION
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_itipversion (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_itipversion (value), NULL);
}

/**
 * i_cal_property_get_itipversion:
 * @self: the #ICalProperty of ITIPVERSION
 *
 * Returns value of the ITIPVERSION @self
 *
 * Returns: the ITIPVERSION value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_itipversion (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_itipversion ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_itipversion:
 * @self: the #ICalProperty of ITIPVERSION
 * @value: the ITIPVERSION value
 *
 * Sets value to the ITIPVERSION @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_itipversion (ICalProperty *self, 
                                const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_itipversion ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_lastmodified:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding LASTMODIFIED.
 *
 * Returns: (transfer full): a new #ICalProperty holding LASTMODIFIED
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_lastmodified (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_lastmodified (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_lastmodified:
 * @self: the #ICalProperty of LASTMODIFIED
 *
 * Returns value of the LASTMODIFIED @self
 *
 * Returns: (transfer full): the LASTMODIFIED value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_lastmodified (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_lastmodified ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_lastmodified:
 * @self: the #ICalProperty of LASTMODIFIED
 * @value: the LASTMODIFIED value
 *
 * Sets value to the LASTMODIFIED @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_lastmodified (ICalProperty *self, 
                                 const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_lastmodified ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_link:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding LINK.
 *
 * Returns: (transfer full): a new #ICalProperty holding LINK
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_link (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_link (value), NULL);
}

/**
 * i_cal_property_get_link:
 * @self: the #ICalProperty of LINK
 *
 * Returns value of the LINK @self
 *
 * Returns: the LINK value
 *
 * Since: 4.0
 *
 **/
const gchar *
i_cal_property_get_link (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_link ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_link:
 * @self: the #ICalProperty of LINK
 * @value: the LINK value
 *
 * Sets value to the LINK @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_link (ICalProperty *self, 
                         const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_link ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_location:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding LOCATION.
 *
 * Returns: (transfer full): a new #ICalProperty holding LOCATION
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_location (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_location (value), NULL);
}

/**
 * i_cal_property_get_location:
 * @self: the #ICalProperty of LOCATION
 *
 * Returns value of the LOCATION @self
 *
 * Returns: the LOCATION value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_location (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_location ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_location:
 * @self: the #ICalProperty of LOCATION
 * @value: the LOCATION value
 *
 * Sets value to the LOCATION @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_location (ICalProperty *self, 
                             const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_location ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_locationtype:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding LOCATIONTYPE.
 *
 * Returns: (transfer full): a new #ICalProperty holding LOCATIONTYPE
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_locationtype (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_locationtype (value), NULL);
}

/**
 * i_cal_property_get_locationtype:
 * @self: the #ICalProperty of LOCATIONTYPE
 *
 * Returns value of the LOCATIONTYPE @self
 *
 * Returns: the LOCATIONTYPE value
 *
 * Since: 4.0
 *
 **/
const gchar *
i_cal_property_get_locationtype (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_locationtype ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_locationtype:
 * @self: the #ICalProperty of LOCATIONTYPE
 * @value: the LOCATIONTYPE value
 *
 * Sets value to the LOCATIONTYPE @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_locationtype (ICalProperty *self, 
                                 const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_locationtype ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_maxcomponentsize:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding MAXCOMPONENTSIZE.
 *
 * Returns: (transfer full): a new #ICalProperty holding MAXCOMPONENTSIZE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_maxcomponentsize (gint value)
{
	return i_cal_property_new_full (icalproperty_new_maxcomponentsize (value), NULL);
}

/**
 * i_cal_property_get_maxcomponentsize:
 * @self: the #ICalProperty of MAXCOMPONENTSIZE
 *
 * Returns value of the MAXCOMPONENTSIZE @self
 *
 * Returns: the MAXCOMPONENTSIZE value
 *
 * Since: 1.0
 *
 **/
gint
i_cal_property_get_maxcomponentsize (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_maxcomponentsize ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_maxcomponentsize:
 * @self: the #ICalProperty of MAXCOMPONENTSIZE
 * @value: the MAXCOMPONENTSIZE value
 *
 * Sets value to the MAXCOMPONENTSIZE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_maxcomponentsize (ICalProperty *self, 
                                     gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_maxcomponentsize ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_maxdate:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding MAXDATE.
 *
 * Returns: (transfer full): a new #ICalProperty holding MAXDATE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_maxdate (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_maxdate (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_maxdate:
 * @self: the #ICalProperty of MAXDATE
 *
 * Returns value of the MAXDATE @self
 *
 * Returns: (transfer full): the MAXDATE value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_maxdate (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_maxdate ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_maxdate:
 * @self: the #ICalProperty of MAXDATE
 * @value: the MAXDATE value
 *
 * Sets value to the MAXDATE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_maxdate (ICalProperty *self, 
                            const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_maxdate ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_maxresults:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding MAXRESULTS.
 *
 * Returns: (transfer full): a new #ICalProperty holding MAXRESULTS
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_maxresults (gint value)
{
	return i_cal_property_new_full (icalproperty_new_maxresults (value), NULL);
}

/**
 * i_cal_property_get_maxresults:
 * @self: the #ICalProperty of MAXRESULTS
 *
 * Returns value of the MAXRESULTS @self
 *
 * Returns: the MAXRESULTS value
 *
 * Since: 1.0
 *
 **/
gint
i_cal_property_get_maxresults (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_maxresults ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_maxresults:
 * @self: the #ICalProperty of MAXRESULTS
 * @value: the MAXRESULTS value
 *
 * Sets value to the MAXRESULTS @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_maxresults (ICalProperty *self, 
                               gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_maxresults ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_maxresultssize:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding MAXRESULTSSIZE.
 *
 * Returns: (transfer full): a new #ICalProperty holding MAXRESULTSSIZE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_maxresultssize (gint value)
{
	return i_cal_property_new_full (icalproperty_new_maxresultssize (value), NULL);
}

/**
 * i_cal_property_get_maxresultssize:
 * @self: the #ICalProperty of MAXRESULTSSIZE
 *
 * Returns value of the MAXRESULTSSIZE @self
 *
 * Returns: the MAXRESULTSSIZE value
 *
 * Since: 1.0
 *
 **/
gint
i_cal_property_get_maxresultssize (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_maxresultssize ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_maxresultssize:
 * @self: the #ICalProperty of MAXRESULTSSIZE
 * @value: the MAXRESULTSSIZE value
 *
 * Sets value to the MAXRESULTSSIZE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_maxresultssize (ICalProperty *self, 
                                   gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_maxresultssize ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_method:
 * @value: the #ICalPropertyMethod value
 *
 * Creates a new #ICalProperty holding METHOD.
 *
 * Returns: (transfer full): a new #ICalProperty holding METHOD
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_method (ICalPropertyMethod value)
{
	return i_cal_property_new_full (icalproperty_new_method ((icalproperty_method) (value)), NULL);
}

/**
 * i_cal_property_get_method:
 * @self: the #ICalProperty of METHOD
 *
 * Returns value of the METHOD @self
 *
 * Returns: the METHOD value
 *
 * Since: 1.0
 *
 **/
ICalPropertyMethod
i_cal_property_get_method (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_METHOD_NONE);

	return (ICalPropertyMethod) (icalproperty_get_method ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_method:
 * @self: the #ICalProperty of METHOD
 * @value: the METHOD value
 *
 * Sets value to the METHOD @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_method (ICalProperty *self, 
                           ICalPropertyMethod value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_method ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_method) (value));
}

/**
 * i_cal_property_new_mindate:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding MINDATE.
 *
 * Returns: (transfer full): a new #ICalProperty holding MINDATE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_mindate (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_mindate (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_mindate:
 * @self: the #ICalProperty of MINDATE
 *
 * Returns value of the MINDATE @self
 *
 * Returns: (transfer full): the MINDATE value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_mindate (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_mindate ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_mindate:
 * @self: the #ICalProperty of MINDATE
 * @value: the MINDATE value
 *
 * Sets value to the MINDATE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_mindate (ICalProperty *self, 
                            const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_mindate ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_multipart:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding MULTIPART.
 *
 * Returns: (transfer full): a new #ICalProperty holding MULTIPART
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_multipart (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_multipart (value), NULL);
}

/**
 * i_cal_property_get_multipart:
 * @self: the #ICalProperty of MULTIPART
 *
 * Returns value of the MULTIPART @self
 *
 * Returns: the MULTIPART value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_multipart (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_multipart ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_multipart:
 * @self: the #ICalProperty of MULTIPART
 * @value: the MULTIPART value
 *
 * Sets value to the MULTIPART @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_multipart (ICalProperty *self, 
                              const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_multipart ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_name:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding NAME.
 *
 * Returns: (transfer full): a new #ICalProperty holding NAME
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_name (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_name (value), NULL);
}

/**
 * i_cal_property_get_name:
 * @self: the #ICalProperty of NAME
 *
 * Returns value of the NAME @self
 *
 * Returns: the NAME value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_name (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_name ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_name:
 * @self: the #ICalProperty of NAME
 * @value: the NAME value
 *
 * Sets value to the NAME @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_name (ICalProperty *self, 
                         const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_name ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_organizer:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding ORGANIZER.
 *
 * Returns: (transfer full): a new #ICalProperty holding ORGANIZER
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_organizer (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_organizer (value), NULL);
}

/**
 * i_cal_property_get_organizer:
 * @self: the #ICalProperty of ORGANIZER
 *
 * Returns value of the ORGANIZER @self
 *
 * Returns: the ORGANIZER value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_organizer (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_organizer ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_organizer:
 * @self: the #ICalProperty of ORGANIZER
 * @value: the ORGANIZER value
 *
 * Sets value to the ORGANIZER @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_organizer (ICalProperty *self, 
                              const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_organizer ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_owner:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding OWNER.
 *
 * Returns: (transfer full): a new #ICalProperty holding OWNER
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_owner (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_owner (value), NULL);
}

/**
 * i_cal_property_get_owner:
 * @self: the #ICalProperty of OWNER
 *
 * Returns value of the OWNER @self
 *
 * Returns: the OWNER value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_owner (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_owner ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_owner:
 * @self: the #ICalProperty of OWNER
 * @value: the OWNER value
 *
 * Sets value to the OWNER @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_owner (ICalProperty *self, 
                          const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_owner ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_participanttype:
 * @value: the #ICalPropertyParticipanttype value
 *
 * Creates a new #ICalProperty holding PARTICIPANTTYPE.
 *
 * Returns: (transfer full): a new #ICalProperty holding PARTICIPANTTYPE
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_participanttype (ICalPropertyParticipanttype value)
{
	return i_cal_property_new_full (icalproperty_new_participanttype ((icalproperty_participanttype) (value)), NULL);
}

/**
 * i_cal_property_get_participanttype:
 * @self: the #ICalProperty of PARTICIPANTTYPE
 *
 * Returns value of the PARTICIPANTTYPE @self
 *
 * Returns: the PARTICIPANTTYPE value
 *
 * Since: 4.0
 *
 **/
ICalPropertyParticipanttype
i_cal_property_get_participanttype (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_PARTICIPANTTYPE_NONE);

	return (ICalPropertyParticipanttype) (icalproperty_get_participanttype ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_participanttype:
 * @self: the #ICalProperty of PARTICIPANTTYPE
 * @value: the PARTICIPANTTYPE value
 *
 * Sets value to the PARTICIPANTTYPE @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_participanttype (ICalProperty *self, 
                                    ICalPropertyParticipanttype value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_participanttype ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_participanttype) (value));
}

/**
 * i_cal_property_new_patchdelete:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding PATCHDELETE.
 *
 * Returns: (transfer full): a new #ICalProperty holding PATCHDELETE
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_patchdelete (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_patchdelete (value), NULL);
}

/**
 * i_cal_property_get_patchdelete:
 * @self: the #ICalProperty of PATCHDELETE
 *
 * Returns value of the PATCHDELETE @self
 *
 * Returns: the PATCHDELETE value
 *
 * Since: 4.0
 *
 **/
const gchar *
i_cal_property_get_patchdelete (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_patchdelete ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_patchdelete:
 * @self: the #ICalProperty of PATCHDELETE
 * @value: the PATCHDELETE value
 *
 * Sets value to the PATCHDELETE @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_patchdelete (ICalProperty *self, 
                                const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_patchdelete ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_patchorder:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding PATCHORDER.
 *
 * Returns: (transfer full): a new #ICalProperty holding PATCHORDER
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_patchorder (gint value)
{
	return i_cal_property_new_full (icalproperty_new_patchorder (value), NULL);
}

/**
 * i_cal_property_get_patchorder:
 * @self: the #ICalProperty of PATCHORDER
 *
 * Returns value of the PATCHORDER @self
 *
 * Returns: the PATCHORDER value
 *
 * Since: 4.0
 *
 **/
gint
i_cal_property_get_patchorder (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_patchorder ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_patchorder:
 * @self: the #ICalProperty of PATCHORDER
 * @value: the PATCHORDER value
 *
 * Sets value to the PATCHORDER @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_patchorder (ICalProperty *self, 
                               gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_patchorder ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_patchparameter:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding PATCHPARAMETER.
 *
 * Returns: (transfer full): a new #ICalProperty holding PATCHPARAMETER
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_patchparameter (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_patchparameter (value), NULL);
}

/**
 * i_cal_property_get_patchparameter:
 * @self: the #ICalProperty of PATCHPARAMETER
 *
 * Returns value of the PATCHPARAMETER @self
 *
 * Returns: the PATCHPARAMETER value
 *
 * Since: 4.0
 *
 **/
const gchar *
i_cal_property_get_patchparameter (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_patchparameter ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_patchparameter:
 * @self: the #ICalProperty of PATCHPARAMETER
 * @value: the PATCHPARAMETER value
 *
 * Sets value to the PATCHPARAMETER @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_patchparameter (ICalProperty *self, 
                                   const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_patchparameter ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_patchtarget:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding PATCHTARGET.
 *
 * Returns: (transfer full): a new #ICalProperty holding PATCHTARGET
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_patchtarget (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_patchtarget (value), NULL);
}

/**
 * i_cal_property_get_patchtarget:
 * @self: the #ICalProperty of PATCHTARGET
 *
 * Returns value of the PATCHTARGET @self
 *
 * Returns: the PATCHTARGET value
 *
 * Since: 4.0
 *
 **/
const gchar *
i_cal_property_get_patchtarget (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_patchtarget ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_patchtarget:
 * @self: the #ICalProperty of PATCHTARGET
 * @value: the PATCHTARGET value
 *
 * Sets value to the PATCHTARGET @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_patchtarget (ICalProperty *self, 
                                const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_patchtarget ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_patchversion:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding PATCHVERSION.
 *
 * Returns: (transfer full): a new #ICalProperty holding PATCHVERSION
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_patchversion (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_patchversion (value), NULL);
}

/**
 * i_cal_property_get_patchversion:
 * @self: the #ICalProperty of PATCHVERSION
 *
 * Returns value of the PATCHVERSION @self
 *
 * Returns: the PATCHVERSION value
 *
 * Since: 4.0
 *
 **/
const gchar *
i_cal_property_get_patchversion (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_patchversion ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_patchversion:
 * @self: the #ICalProperty of PATCHVERSION
 * @value: the PATCHVERSION value
 *
 * Sets value to the PATCHVERSION @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_patchversion (ICalProperty *self, 
                                 const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_patchversion ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_percentcomplete:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding PERCENTCOMPLETE.
 *
 * Returns: (transfer full): a new #ICalProperty holding PERCENTCOMPLETE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_percentcomplete (gint value)
{
	return i_cal_property_new_full (icalproperty_new_percentcomplete (value), NULL);
}

/**
 * i_cal_property_get_percentcomplete:
 * @self: the #ICalProperty of PERCENTCOMPLETE
 *
 * Returns value of the PERCENTCOMPLETE @self
 *
 * Returns: the PERCENTCOMPLETE value
 *
 * Since: 1.0
 *
 **/
gint
i_cal_property_get_percentcomplete (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_percentcomplete ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_percentcomplete:
 * @self: the #ICalProperty of PERCENTCOMPLETE
 * @value: the PERCENTCOMPLETE value
 *
 * Sets value to the PERCENTCOMPLETE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_percentcomplete (ICalProperty *self, 
                                    gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_percentcomplete ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_permission:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding PERMISSION.
 *
 * Returns: (transfer full): a new #ICalProperty holding PERMISSION
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_permission (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_permission (value), NULL);
}

/**
 * i_cal_property_get_permission:
 * @self: the #ICalProperty of PERMISSION
 *
 * Returns value of the PERMISSION @self
 *
 * Returns: the PERMISSION value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_permission (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_permission ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_permission:
 * @self: the #ICalProperty of PERMISSION
 * @value: the PERMISSION value
 *
 * Sets value to the PERMISSION @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_permission (ICalProperty *self, 
                               const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_permission ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_pollcompletion:
 * @value: the #ICalPropertyPollcompletion value
 *
 * Creates a new #ICalProperty holding POLLCOMPLETION.
 *
 * Returns: (transfer full): a new #ICalProperty holding POLLCOMPLETION
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_pollcompletion (ICalPropertyPollcompletion value)
{
	return i_cal_property_new_full (icalproperty_new_pollcompletion ((icalproperty_pollcompletion) (value)), NULL);
}

/**
 * i_cal_property_get_pollcompletion:
 * @self: the #ICalProperty of POLLCOMPLETION
 *
 * Returns value of the POLLCOMPLETION @self
 *
 * Returns: the POLLCOMPLETION value
 *
 * Since: 1.0
 *
 **/
ICalPropertyPollcompletion
i_cal_property_get_pollcompletion (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_POLLCOMPLETION_NONE);

	return (ICalPropertyPollcompletion) (icalproperty_get_pollcompletion ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_pollcompletion:
 * @self: the #ICalProperty of POLLCOMPLETION
 * @value: the POLLCOMPLETION value
 *
 * Sets value to the POLLCOMPLETION @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_pollcompletion (ICalProperty *self, 
                                   ICalPropertyPollcompletion value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_pollcompletion ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_pollcompletion) (value));
}

/**
 * i_cal_property_new_pollitemid:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding POLLITEMID.
 *
 * Returns: (transfer full): a new #ICalProperty holding POLLITEMID
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_pollitemid (gint value)
{
	return i_cal_property_new_full (icalproperty_new_pollitemid (value), NULL);
}

/**
 * i_cal_property_get_pollitemid:
 * @self: the #ICalProperty of POLLITEMID
 *
 * Returns value of the POLLITEMID @self
 *
 * Returns: the POLLITEMID value
 *
 * Since: 1.0
 *
 **/
gint
i_cal_property_get_pollitemid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_pollitemid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_pollitemid:
 * @self: the #ICalProperty of POLLITEMID
 * @value: the POLLITEMID value
 *
 * Sets value to the POLLITEMID @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_pollitemid (ICalProperty *self, 
                               gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_pollitemid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_pollmode:
 * @value: the #ICalPropertyPollmode value
 *
 * Creates a new #ICalProperty holding POLLMODE.
 *
 * Returns: (transfer full): a new #ICalProperty holding POLLMODE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_pollmode (ICalPropertyPollmode value)
{
	return i_cal_property_new_full (icalproperty_new_pollmode ((icalproperty_pollmode) (value)), NULL);
}

/**
 * i_cal_property_get_pollmode:
 * @self: the #ICalProperty of POLLMODE
 *
 * Returns value of the POLLMODE @self
 *
 * Returns: the POLLMODE value
 *
 * Since: 1.0
 *
 **/
ICalPropertyPollmode
i_cal_property_get_pollmode (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_POLLMODE_NONE);

	return (ICalPropertyPollmode) (icalproperty_get_pollmode ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_pollmode:
 * @self: the #ICalProperty of POLLMODE
 * @value: the POLLMODE value
 *
 * Sets value to the POLLMODE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_pollmode (ICalProperty *self, 
                             ICalPropertyPollmode value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_pollmode ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_pollmode) (value));
}

/**
 * i_cal_property_new_pollproperties:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding POLLPROPERTIES.
 *
 * Returns: (transfer full): a new #ICalProperty holding POLLPROPERTIES
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_pollproperties (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_pollproperties (value), NULL);
}

/**
 * i_cal_property_get_pollproperties:
 * @self: the #ICalProperty of POLLPROPERTIES
 *
 * Returns value of the POLLPROPERTIES @self
 *
 * Returns: the POLLPROPERTIES value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_pollproperties (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_pollproperties ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_pollproperties:
 * @self: the #ICalProperty of POLLPROPERTIES
 * @value: the POLLPROPERTIES value
 *
 * Sets value to the POLLPROPERTIES @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_pollproperties (ICalProperty *self, 
                                   const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_pollproperties ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_pollwinner:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding POLLWINNER.
 *
 * Returns: (transfer full): a new #ICalProperty holding POLLWINNER
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_pollwinner (gint value)
{
	return i_cal_property_new_full (icalproperty_new_pollwinner (value), NULL);
}

/**
 * i_cal_property_get_pollwinner:
 * @self: the #ICalProperty of POLLWINNER
 *
 * Returns value of the POLLWINNER @self
 *
 * Returns: the POLLWINNER value
 *
 * Since: 1.0
 *
 **/
gint
i_cal_property_get_pollwinner (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_pollwinner ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_pollwinner:
 * @self: the #ICalProperty of POLLWINNER
 * @value: the POLLWINNER value
 *
 * Sets value to the POLLWINNER @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_pollwinner (ICalProperty *self, 
                               gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_pollwinner ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_priority:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding PRIORITY.
 *
 * Returns: (transfer full): a new #ICalProperty holding PRIORITY
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_priority (gint value)
{
	return i_cal_property_new_full (icalproperty_new_priority (value), NULL);
}

/**
 * i_cal_property_get_priority:
 * @self: the #ICalProperty of PRIORITY
 *
 * Returns value of the PRIORITY @self
 *
 * Returns: the PRIORITY value
 *
 * Since: 1.0
 *
 **/
gint
i_cal_property_get_priority (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_priority ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_priority:
 * @self: the #ICalProperty of PRIORITY
 * @value: the PRIORITY value
 *
 * Sets value to the PRIORITY @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_priority (ICalProperty *self, 
                             gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_priority ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_prodid:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding PRODID.
 *
 * Returns: (transfer full): a new #ICalProperty holding PRODID
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_prodid (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_prodid (value), NULL);
}

/**
 * i_cal_property_get_prodid:
 * @self: the #ICalProperty of PRODID
 *
 * Returns value of the PRODID @self
 *
 * Returns: the PRODID value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_prodid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_prodid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_prodid:
 * @self: the #ICalProperty of PRODID
 * @value: the PRODID value
 *
 * Sets value to the PRODID @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_prodid (ICalProperty *self, 
                           const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_prodid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_proximity:
 * @value: the #ICalPropertyProximity value
 *
 * Creates a new #ICalProperty holding PROXIMITY.
 *
 * Returns: (transfer full): a new #ICalProperty holding PROXIMITY
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_proximity (ICalPropertyProximity value)
{
	return i_cal_property_new_full (icalproperty_new_proximity ((icalproperty_proximity) (value)), NULL);
}

/**
 * i_cal_property_get_proximity:
 * @self: the #ICalProperty of PROXIMITY
 *
 * Returns value of the PROXIMITY @self
 *
 * Returns: the PROXIMITY value
 *
 * Since: 4.0
 *
 **/
ICalPropertyProximity
i_cal_property_get_proximity (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_PROXIMITY_NONE);

	return (ICalPropertyProximity) (icalproperty_get_proximity ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_proximity:
 * @self: the #ICalProperty of PROXIMITY
 * @value: the PROXIMITY value
 *
 * Sets value to the PROXIMITY @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_proximity (ICalProperty *self, 
                              ICalPropertyProximity value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_proximity ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_proximity) (value));
}

/**
 * i_cal_property_new_query:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding QUERY.
 *
 * Returns: (transfer full): a new #ICalProperty holding QUERY
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_query (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_query (value), NULL);
}

/**
 * i_cal_property_get_query:
 * @self: the #ICalProperty of QUERY
 *
 * Returns value of the QUERY @self
 *
 * Returns: the QUERY value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_query (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_query ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_query:
 * @self: the #ICalProperty of QUERY
 * @value: the QUERY value
 *
 * Sets value to the QUERY @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_query (ICalProperty *self, 
                          const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_query ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_querylevel:
 * @value: the #ICalPropertyQuerylevel value
 *
 * Creates a new #ICalProperty holding QUERYLEVEL.
 *
 * Returns: (transfer full): a new #ICalProperty holding QUERYLEVEL
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_querylevel (ICalPropertyQuerylevel value)
{
	return i_cal_property_new_full (icalproperty_new_querylevel ((icalproperty_querylevel) (value)), NULL);
}

/**
 * i_cal_property_get_querylevel:
 * @self: the #ICalProperty of QUERYLEVEL
 *
 * Returns value of the QUERYLEVEL @self
 *
 * Returns: the QUERYLEVEL value
 *
 * Since: 1.0
 *
 **/
ICalPropertyQuerylevel
i_cal_property_get_querylevel (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_QUERYLEVEL_NONE);

	return (ICalPropertyQuerylevel) (icalproperty_get_querylevel ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_querylevel:
 * @self: the #ICalProperty of QUERYLEVEL
 * @value: the QUERYLEVEL value
 *
 * Sets value to the QUERYLEVEL @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_querylevel (ICalProperty *self, 
                               ICalPropertyQuerylevel value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_querylevel ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_querylevel) (value));
}

/**
 * i_cal_property_new_queryid:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding QUERYID.
 *
 * Returns: (transfer full): a new #ICalProperty holding QUERYID
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_queryid (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_queryid (value), NULL);
}

/**
 * i_cal_property_get_queryid:
 * @self: the #ICalProperty of QUERYID
 *
 * Returns value of the QUERYID @self
 *
 * Returns: the QUERYID value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_queryid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_queryid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_queryid:
 * @self: the #ICalProperty of QUERYID
 * @value: the QUERYID value
 *
 * Sets value to the QUERYID @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_queryid (ICalProperty *self, 
                            const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_queryid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_queryname:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding QUERYNAME.
 *
 * Returns: (transfer full): a new #ICalProperty holding QUERYNAME
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_queryname (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_queryname (value), NULL);
}

/**
 * i_cal_property_get_queryname:
 * @self: the #ICalProperty of QUERYNAME
 *
 * Returns value of the QUERYNAME @self
 *
 * Returns: the QUERYNAME value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_queryname (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_queryname ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_queryname:
 * @self: the #ICalProperty of QUERYNAME
 * @value: the QUERYNAME value
 *
 * Sets value to the QUERYNAME @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_queryname (ICalProperty *self, 
                              const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_queryname ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_rdate:
 * @value: the #ICalDatetimeperiod value
 *
 * Creates a new #ICalProperty holding RDATE.
 *
 * Returns: (transfer full): a new #ICalProperty holding RDATE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_rdate (const ICalDatetimeperiod *value)
{
    g_return_val_if_fail (I_CAL_IS_DATETIMEPERIOD ((ICalDatetimeperiod*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_rdate (* (struct icaldatetimeperiodtype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_rdate:
 * @self: the #ICalProperty of RDATE
 *
 * Returns value of the RDATE @self
 *
 * Returns: (transfer full): the RDATE value
 *
 * Since: 1.0
 *
 **/
ICalDatetimeperiod *
i_cal_property_get_rdate (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_datetimeperiod_new_full (icalproperty_get_rdate ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_rdate:
 * @self: the #ICalProperty of RDATE
 * @value: the RDATE value
 *
 * Sets value to the RDATE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_rdate (ICalProperty *self, 
                          const ICalDatetimeperiod *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_DATETIMEPERIOD ((ICalDatetimeperiod*)value));

	icalproperty_set_rdate ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaldatetimeperiodtype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_recuraccepted:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding RECURACCEPTED.
 *
 * Returns: (transfer full): a new #ICalProperty holding RECURACCEPTED
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_recuraccepted (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_recuraccepted (value), NULL);
}

/**
 * i_cal_property_get_recuraccepted:
 * @self: the #ICalProperty of RECURACCEPTED
 *
 * Returns value of the RECURACCEPTED @self
 *
 * Returns: the RECURACCEPTED value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_recuraccepted (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_recuraccepted ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_recuraccepted:
 * @self: the #ICalProperty of RECURACCEPTED
 * @value: the RECURACCEPTED value
 *
 * Sets value to the RECURACCEPTED @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_recuraccepted (ICalProperty *self, 
                                  const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_recuraccepted ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_recurexpand:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding RECUREXPAND.
 *
 * Returns: (transfer full): a new #ICalProperty holding RECUREXPAND
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_recurexpand (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_recurexpand (value), NULL);
}

/**
 * i_cal_property_get_recurexpand:
 * @self: the #ICalProperty of RECUREXPAND
 *
 * Returns value of the RECUREXPAND @self
 *
 * Returns: the RECUREXPAND value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_recurexpand (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_recurexpand ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_recurexpand:
 * @self: the #ICalProperty of RECUREXPAND
 * @value: the RECUREXPAND value
 *
 * Sets value to the RECUREXPAND @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_recurexpand (ICalProperty *self, 
                                const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_recurexpand ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_recurlimit:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding RECURLIMIT.
 *
 * Returns: (transfer full): a new #ICalProperty holding RECURLIMIT
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_recurlimit (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_recurlimit (value), NULL);
}

/**
 * i_cal_property_get_recurlimit:
 * @self: the #ICalProperty of RECURLIMIT
 *
 * Returns value of the RECURLIMIT @self
 *
 * Returns: the RECURLIMIT value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_recurlimit (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_recurlimit ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_recurlimit:
 * @self: the #ICalProperty of RECURLIMIT
 * @value: the RECURLIMIT value
 *
 * Sets value to the RECURLIMIT @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_recurlimit (ICalProperty *self, 
                               const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_recurlimit ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_recurrenceid:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding RECURRENCEID.
 *
 * Returns: (transfer full): a new #ICalProperty holding RECURRENCEID
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_recurrenceid (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_recurrenceid (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_recurrenceid:
 * @self: the #ICalProperty of RECURRENCEID
 *
 * Returns value of the RECURRENCEID @self
 *
 * Returns: (transfer full): the RECURRENCEID value
 *
 * Since: 1.0
 *
 **/
ICalTime *
i_cal_property_get_recurrenceid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_recurrenceid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_recurrenceid:
 * @self: the #ICalProperty of RECURRENCEID
 * @value: the RECURRENCEID value
 *
 * Sets value to the RECURRENCEID @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_recurrenceid (ICalProperty *self, 
                                 const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_recurrenceid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_refid:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding REFID.
 *
 * Returns: (transfer full): a new #ICalProperty holding REFID
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_refid (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_refid (value), NULL);
}

/**
 * i_cal_property_get_refid:
 * @self: the #ICalProperty of REFID
 *
 * Returns value of the REFID @self
 *
 * Returns: the REFID value
 *
 * Since: 4.0
 *
 **/
const gchar *
i_cal_property_get_refid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_refid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_refid:
 * @self: the #ICalProperty of REFID
 * @value: the REFID value
 *
 * Sets value to the REFID @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_refid (ICalProperty *self, 
                          const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_refid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_refreshinterval:
 * @value: the #ICalDuration value
 *
 * Creates a new #ICalProperty holding REFRESHINTERVAL.
 *
 * Returns: (transfer full): a new #ICalProperty holding REFRESHINTERVAL
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_refreshinterval (const ICalDuration *value)
{
    g_return_val_if_fail (I_CAL_IS_DURATION ((ICalDuration*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_refreshinterval (* (struct icaldurationtype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_refreshinterval:
 * @self: the #ICalProperty of REFRESHINTERVAL
 *
 * Returns value of the REFRESHINTERVAL @self
 *
 * Returns: (transfer full): the REFRESHINTERVAL value
 *
 * Since: 4.0
 *
 **/
ICalDuration *
i_cal_property_get_refreshinterval (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_duration_new_full (icalproperty_get_refreshinterval ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_refreshinterval:
 * @self: the #ICalProperty of REFRESHINTERVAL
 * @value: the REFRESHINTERVAL value
 *
 * Sets value to the REFRESHINTERVAL @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_refreshinterval (ICalProperty *self, 
                                    const ICalDuration *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_DURATION ((ICalDuration*)value));

	icalproperty_set_refreshinterval ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaldurationtype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_relatedto:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding RELATEDTO.
 *
 * Returns: (transfer full): a new #ICalProperty holding RELATEDTO
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_relatedto (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_relatedto (value), NULL);
}

/**
 * i_cal_property_get_relatedto:
 * @self: the #ICalProperty of RELATEDTO
 *
 * Returns value of the RELATEDTO @self
 *
 * Returns: the RELATEDTO value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_relatedto (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_relatedto ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_relatedto:
 * @self: the #ICalProperty of RELATEDTO
 * @value: the RELATEDTO value
 *
 * Sets value to the RELATEDTO @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_relatedto (ICalProperty *self, 
                              const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_relatedto ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_relcalid:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding RELCALID.
 *
 * Returns: (transfer full): a new #ICalProperty holding RELCALID
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_relcalid (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_relcalid (value), NULL);
}

/**
 * i_cal_property_get_relcalid:
 * @self: the #ICalProperty of RELCALID
 *
 * Returns value of the RELCALID @self
 *
 * Returns: the RELCALID value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_relcalid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_relcalid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_relcalid:
 * @self: the #ICalProperty of RELCALID
 * @value: the RELCALID value
 *
 * Sets value to the RELCALID @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_relcalid (ICalProperty *self, 
                             const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_relcalid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_repeat:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding REPEAT.
 *
 * Returns: (transfer full): a new #ICalProperty holding REPEAT
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_repeat (gint value)
{
	return i_cal_property_new_full (icalproperty_new_repeat (value), NULL);
}

/**
 * i_cal_property_get_repeat:
 * @self: the #ICalProperty of REPEAT
 *
 * Returns value of the REPEAT @self
 *
 * Returns: the REPEAT value
 *
 * Since: 1.0
 *
 **/
gint
i_cal_property_get_repeat (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_repeat ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_repeat:
 * @self: the #ICalProperty of REPEAT
 * @value: the REPEAT value
 *
 * Sets value to the REPEAT @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_repeat (ICalProperty *self, 
                           gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_repeat ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_replyurl:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding REPLYURL.
 *
 * Returns: (transfer full): a new #ICalProperty holding REPLYURL
 *
 * Since: 2.0
 *
 **/
ICalProperty *
i_cal_property_new_replyurl (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_replyurl (value), NULL);
}

/**
 * i_cal_property_get_replyurl:
 * @self: the #ICalProperty of REPLYURL
 *
 * Returns value of the REPLYURL @self
 *
 * Returns: the REPLYURL value
 *
 * Since: 2.0
 *
 **/
const gchar *
i_cal_property_get_replyurl (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_replyurl ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_replyurl:
 * @self: the #ICalProperty of REPLYURL
 * @value: the REPLYURL value
 *
 * Sets value to the REPLYURL @self
 *
 * Since: 2.0
 *
 **/
void
i_cal_property_set_replyurl (ICalProperty *self, 
                             const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_replyurl ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_requeststatus:
 * @value: the #ICalReqstat value
 *
 * Creates a new #ICalProperty holding REQUESTSTATUS.
 *
 * Returns: (transfer full): a new #ICalProperty holding REQUESTSTATUS
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_requeststatus (const ICalReqstat *value)
{
    g_return_val_if_fail (I_CAL_IS_REQSTAT ((ICalReqstat*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_requeststatus (* (struct icalreqstattype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_requeststatus:
 * @self: the #ICalProperty of REQUESTSTATUS
 *
 * Returns value of the REQUESTSTATUS @self
 *
 * Returns: (transfer full): the REQUESTSTATUS value
 *
 * Since: 1.0
 *
 **/
ICalReqstat *
i_cal_property_get_requeststatus (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_reqstat_new_full (icalproperty_get_requeststatus ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_requeststatus:
 * @self: the #ICalProperty of REQUESTSTATUS
 * @value: the REQUESTSTATUS value
 *
 * Sets value to the REQUESTSTATUS @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_requeststatus (ICalProperty *self, 
                                  const ICalReqstat *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_REQSTAT ((ICalReqstat*)value));

	icalproperty_set_requeststatus ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icalreqstattype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_resources:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding RESOURCES.
 *
 * Returns: (transfer full): a new #ICalProperty holding RESOURCES
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_resources (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_resources (value), NULL);
}

/**
 * i_cal_property_get_resources:
 * @self: the #ICalProperty of RESOURCES
 *
 * Returns value of the RESOURCES @self
 *
 * Returns: the RESOURCES value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_resources (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_resources ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_resources:
 * @self: the #ICalProperty of RESOURCES
 * @value: the RESOURCES value
 *
 * Sets value to the RESOURCES @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_resources (ICalProperty *self, 
                              const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_resources ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_resourcetype:
 * @value: the #ICalPropertyResourcetype value
 *
 * Creates a new #ICalProperty holding RESOURCETYPE.
 *
 * Returns: (transfer full): a new #ICalProperty holding RESOURCETYPE
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_resourcetype (ICalPropertyResourcetype value)
{
	return i_cal_property_new_full (icalproperty_new_resourcetype ((icalproperty_resourcetype) (value)), NULL);
}

/**
 * i_cal_property_get_resourcetype:
 * @self: the #ICalProperty of RESOURCETYPE
 *
 * Returns value of the RESOURCETYPE @self
 *
 * Returns: the RESOURCETYPE value
 *
 * Since: 4.0
 *
 **/
ICalPropertyResourcetype
i_cal_property_get_resourcetype (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_RESOURCETYPE_NONE);

	return (ICalPropertyResourcetype) (icalproperty_get_resourcetype ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_resourcetype:
 * @self: the #ICalProperty of RESOURCETYPE
 * @value: the RESOURCETYPE value
 *
 * Sets value to the RESOURCETYPE @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_resourcetype (ICalProperty *self, 
                                 ICalPropertyResourcetype value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_resourcetype ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_resourcetype) (value));
}

/**
 * i_cal_property_new_response:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding RESPONSE.
 *
 * Returns: (transfer full): a new #ICalProperty holding RESPONSE
 *
 * Since: 2.0
 *
 **/
ICalProperty *
i_cal_property_new_response (gint value)
{
	return i_cal_property_new_full (icalproperty_new_response (value), NULL);
}

/**
 * i_cal_property_get_response:
 * @self: the #ICalProperty of RESPONSE
 *
 * Returns value of the RESPONSE @self
 *
 * Returns: the RESPONSE value
 *
 * Since: 2.0
 *
 **/
gint
i_cal_property_get_response (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_response ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_response:
 * @self: the #ICalProperty of RESPONSE
 * @value: the RESPONSE value
 *
 * Sets value to the RESPONSE @self
 *
 * Since: 2.0
 *
 **/
void
i_cal_property_set_response (ICalProperty *self, 
                             gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_response ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_restriction:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding RESTRICTION.
 *
 * Returns: (transfer full): a new #ICalProperty holding RESTRICTION
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_restriction (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_restriction (value), NULL);
}

/**
 * i_cal_property_get_restriction:
 * @self: the #ICalProperty of RESTRICTION
 *
 * Returns value of the RESTRICTION @self
 *
 * Returns: the RESTRICTION value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_restriction (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_restriction ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_restriction:
 * @self: the #ICalProperty of RESTRICTION
 * @value: the RESTRICTION value
 *
 * Sets value to the RESTRICTION @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_restriction (ICalProperty *self, 
                                const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_restriction ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_rrule:
 * @value: the #ICalRecurrence value
 *
 * Creates a new #ICalProperty holding RRULE.
 *
 * Returns: (transfer full): a new #ICalProperty holding RRULE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_rrule (const ICalRecurrence *value)
{
    g_return_val_if_fail (I_CAL_IS_RECURRENCE ((ICalRecurrence*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_rrule ((struct icalrecurrencetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_rrule:
 * @self: the #ICalProperty of RRULE
 *
 * Returns value of the RRULE @self
 *
 * Returns: (transfer full): the RRULE value
 *
 * Since: 1.0
 *
 **/
ICalRecurrence *
i_cal_property_get_rrule (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_recurrence_new_full (icalproperty_get_rrule ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))), (GObject *)self);
}

/**
 * i_cal_property_set_rrule:
 * @self: the #ICalProperty of RRULE
 * @value: the RRULE value
 *
 * Sets value to the RRULE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_rrule (ICalProperty *self, 
                          const ICalRecurrence *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_RECURRENCE ((ICalRecurrence*)value));

	icalproperty_set_rrule ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (struct icalrecurrencetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_scope:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding SCOPE.
 *
 * Returns: (transfer full): a new #ICalProperty holding SCOPE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_scope (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_scope (value), NULL);
}

/**
 * i_cal_property_get_scope:
 * @self: the #ICalProperty of SCOPE
 *
 * Returns value of the SCOPE @self
 *
 * Returns: the SCOPE value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_scope (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_scope ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_scope:
 * @self: the #ICalProperty of SCOPE
 * @value: the SCOPE value
 *
 * Sets value to the SCOPE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_scope (ICalProperty *self, 
                          const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_scope ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_sequence:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding SEQUENCE.
 *
 * Returns: (transfer full): a new #ICalProperty holding SEQUENCE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_sequence (gint value)
{
	return i_cal_property_new_full (icalproperty_new_sequence (value), NULL);
}

/**
 * i_cal_property_get_sequence:
 * @self: the #ICalProperty of SEQUENCE
 *
 * Returns value of the SEQUENCE @self
 *
 * Returns: the SEQUENCE value
 *
 * Since: 1.0
 *
 **/
gint
i_cal_property_get_sequence (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_sequence ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_sequence:
 * @self: the #ICalProperty of SEQUENCE
 * @value: the SEQUENCE value
 *
 * Sets value to the SEQUENCE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_sequence (ICalProperty *self, 
                             gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_sequence ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_source:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding SOURCE.
 *
 * Returns: (transfer full): a new #ICalProperty holding SOURCE
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_source (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_source (value), NULL);
}

/**
 * i_cal_property_get_source:
 * @self: the #ICalProperty of SOURCE
 *
 * Returns value of the SOURCE @self
 *
 * Returns: the SOURCE value
 *
 * Since: 4.0
 *
 **/
const gchar *
i_cal_property_get_source (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_source ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_source:
 * @self: the #ICalProperty of SOURCE
 * @value: the SOURCE value
 *
 * Sets value to the SOURCE @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_source (ICalProperty *self, 
                           const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_source ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_status:
 * @value: the #ICalPropertyStatus value
 *
 * Creates a new #ICalProperty holding STATUS.
 *
 * Returns: (transfer full): a new #ICalProperty holding STATUS
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_status (ICalPropertyStatus value)
{
	return i_cal_property_new_full (icalproperty_new_status ((icalproperty_status) (value)), NULL);
}

/**
 * i_cal_property_get_status:
 * @self: the #ICalProperty of STATUS
 *
 * Returns value of the STATUS @self
 *
 * Returns: the STATUS value
 *
 * Since: 1.0
 *
 **/
ICalPropertyStatus
i_cal_property_get_status (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_STATUS_NONE);

	return (ICalPropertyStatus) (icalproperty_get_status ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_status:
 * @self: the #ICalProperty of STATUS
 * @value: the STATUS value
 *
 * Sets value to the STATUS @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_status (ICalProperty *self, 
                           ICalPropertyStatus value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_status ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_status) (value));
}

/**
 * i_cal_property_new_storesexpanded:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding STORESEXPANDED.
 *
 * Returns: (transfer full): a new #ICalProperty holding STORESEXPANDED
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_storesexpanded (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_storesexpanded (value), NULL);
}

/**
 * i_cal_property_get_storesexpanded:
 * @self: the #ICalProperty of STORESEXPANDED
 *
 * Returns value of the STORESEXPANDED @self
 *
 * Returns: the STORESEXPANDED value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_storesexpanded (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_storesexpanded ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_storesexpanded:
 * @self: the #ICalProperty of STORESEXPANDED
 * @value: the STORESEXPANDED value
 *
 * Sets value to the STORESEXPANDED @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_storesexpanded (ICalProperty *self, 
                                   const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_storesexpanded ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_structureddata:
 * @value: the #ICalAttach value
 *
 * Creates a new #ICalProperty holding STRUCTUREDDATA.
 *
 * Returns: (transfer full): a new #ICalProperty holding STRUCTUREDDATA
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_structureddata (const ICalAttach *value)
{
    g_return_val_if_fail (I_CAL_IS_ATTACH ((ICalAttach*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_structureddata ((icalattach *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_structureddata:
 * @self: the #ICalProperty of STRUCTUREDDATA
 *
 * Returns value of the STRUCTUREDDATA @self
 *
 * Returns: (transfer full): the STRUCTUREDDATA value
 *
 * Since: 4.0
 *
 **/
ICalAttach *
i_cal_property_get_structureddata (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_attach_new_full (icalproperty_get_structureddata ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))), (GObject *)self);
}

/**
 * i_cal_property_set_structureddata:
 * @self: the #ICalProperty of STRUCTUREDDATA
 * @value: the STRUCTUREDDATA value
 *
 * Sets value to the STRUCTUREDDATA @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_structureddata (ICalProperty *self, 
                                   const ICalAttach *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_ATTACH ((ICalAttach*)value));

	icalproperty_set_structureddata ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalattach *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_styleddescription:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding STYLEDDESCRIPTION.
 *
 * Returns: (transfer full): a new #ICalProperty holding STYLEDDESCRIPTION
 *
 * Since: 4.0
 *
 **/
ICalProperty *
i_cal_property_new_styleddescription (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_styleddescription (value), NULL);
}

/**
 * i_cal_property_get_styleddescription:
 * @self: the #ICalProperty of STYLEDDESCRIPTION
 *
 * Returns value of the STYLEDDESCRIPTION @self
 *
 * Returns: the STYLEDDESCRIPTION value
 *
 * Since: 4.0
 *
 **/
const gchar *
i_cal_property_get_styleddescription (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_styleddescription ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_styleddescription:
 * @self: the #ICalProperty of STYLEDDESCRIPTION
 * @value: the STYLEDDESCRIPTION value
 *
 * Sets value to the STYLEDDESCRIPTION @self
 *
 * Since: 4.0
 *
 **/
void
i_cal_property_set_styleddescription (ICalProperty *self, 
                                      const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_styleddescription ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_summary:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding SUMMARY.
 *
 * Returns: (transfer full): a new #ICalProperty holding SUMMARY
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_summary (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_summary (value), NULL);
}

/**
 * i_cal_property_get_summary:
 * @self: the #ICalProperty of SUMMARY
 *
 * Returns value of the SUMMARY @self
 *
 * Returns: the SUMMARY value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_summary (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_summary ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_summary:
 * @self: the #ICalProperty of SUMMARY
 * @value: the SUMMARY value
 *
 * Sets value to the SUMMARY @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_summary (ICalProperty *self, 
                            const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_summary ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_target:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding TARGET.
 *
 * Returns: (transfer full): a new #ICalProperty holding TARGET
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_target (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_target (value), NULL);
}

/**
 * i_cal_property_get_target:
 * @self: the #ICalProperty of TARGET
 *
 * Returns value of the TARGET @self
 *
 * Returns: the TARGET value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_target (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_target ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_target:
 * @self: the #ICalProperty of TARGET
 * @value: the TARGET value
 *
 * Sets value to the TARGET @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_target (ICalProperty *self, 
                           const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_target ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_taskmode:
 * @value: the #ICalPropertyTaskmode value
 *
 * Creates a new #ICalProperty holding TASKMODE.
 *
 * Returns: (transfer full): a new #ICalProperty holding TASKMODE
 *
 * Since: 2.0
 *
 **/
ICalProperty *
i_cal_property_new_taskmode (ICalPropertyTaskmode value)
{
	return i_cal_property_new_full (icalproperty_new_taskmode ((icalproperty_taskmode) (value)), NULL);
}

/**
 * i_cal_property_get_taskmode:
 * @self: the #ICalProperty of TASKMODE
 *
 * Returns value of the TASKMODE @self
 *
 * Returns: the TASKMODE value
 *
 * Since: 2.0
 *
 **/
ICalPropertyTaskmode
i_cal_property_get_taskmode (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_TASKMODE_NONE);

	return (ICalPropertyTaskmode) (icalproperty_get_taskmode ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_taskmode:
 * @self: the #ICalProperty of TASKMODE
 * @value: the TASKMODE value
 *
 * Sets value to the TASKMODE @self
 *
 * Since: 2.0
 *
 **/
void
i_cal_property_set_taskmode (ICalProperty *self, 
                             ICalPropertyTaskmode value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_taskmode ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_taskmode) (value));
}

/**
 * i_cal_property_new_transp:
 * @value: the #ICalPropertyTransp value
 *
 * Creates a new #ICalProperty holding TRANSP.
 *
 * Returns: (transfer full): a new #ICalProperty holding TRANSP
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_transp (ICalPropertyTransp value)
{
	return i_cal_property_new_full (icalproperty_new_transp ((icalproperty_transp) (value)), NULL);
}

/**
 * i_cal_property_get_transp:
 * @self: the #ICalProperty of TRANSP
 *
 * Returns value of the TRANSP @self
 *
 * Returns: the TRANSP value
 *
 * Since: 1.0
 *
 **/
ICalPropertyTransp
i_cal_property_get_transp (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_TRANSP_NONE);

	return (ICalPropertyTransp) (icalproperty_get_transp ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_transp:
 * @self: the #ICalProperty of TRANSP
 * @value: the TRANSP value
 *
 * Sets value to the TRANSP @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_transp (ICalProperty *self, 
                           ICalPropertyTransp value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_transp ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_transp) (value));
}

/**
 * i_cal_property_new_trigger:
 * @value: the #ICalTrigger value
 *
 * Creates a new #ICalProperty holding TRIGGER.
 *
 * Returns: (transfer full): a new #ICalProperty holding TRIGGER
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_trigger (const ICalTrigger *value)
{
    g_return_val_if_fail (I_CAL_IS_TRIGGER ((ICalTrigger*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_trigger (* (struct icaltriggertype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_trigger:
 * @self: the #ICalProperty of TRIGGER
 *
 * Returns value of the TRIGGER @self
 *
 * Returns: (transfer full): the TRIGGER value
 *
 * Since: 1.0
 *
 **/
ICalTrigger *
i_cal_property_get_trigger (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_trigger_new_full (icalproperty_get_trigger ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_trigger:
 * @self: the #ICalProperty of TRIGGER
 * @value: the TRIGGER value
 *
 * Sets value to the TRIGGER @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_trigger (ICalProperty *self, 
                            const ICalTrigger *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TRIGGER ((ICalTrigger*)value));

	icalproperty_set_trigger ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltriggertype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_tzid:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding TZID.
 *
 * Returns: (transfer full): a new #ICalProperty holding TZID
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_tzid (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_tzid (value), NULL);
}

/**
 * i_cal_property_get_tzid:
 * @self: the #ICalProperty of TZID
 *
 * Returns value of the TZID @self
 *
 * Returns: the TZID value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_tzid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_tzid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_tzid:
 * @self: the #ICalProperty of TZID
 * @value: the TZID value
 *
 * Sets value to the TZID @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_tzid (ICalProperty *self, 
                         const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_tzid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_tzidaliasof:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding TZIDALIASOF.
 *
 * Returns: (transfer full): a new #ICalProperty holding TZIDALIASOF
 *
 * Since: 2.0
 *
 **/
ICalProperty *
i_cal_property_new_tzidaliasof (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_tzidaliasof (value), NULL);
}

/**
 * i_cal_property_get_tzidaliasof:
 * @self: the #ICalProperty of TZIDALIASOF
 *
 * Returns value of the TZIDALIASOF @self
 *
 * Returns: the TZIDALIASOF value
 *
 * Since: 2.0
 *
 **/
const gchar *
i_cal_property_get_tzidaliasof (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_tzidaliasof ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_tzidaliasof:
 * @self: the #ICalProperty of TZIDALIASOF
 * @value: the TZIDALIASOF value
 *
 * Sets value to the TZIDALIASOF @self
 *
 * Since: 2.0
 *
 **/
void
i_cal_property_set_tzidaliasof (ICalProperty *self, 
                                const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_tzidaliasof ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_tzname:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding TZNAME.
 *
 * Returns: (transfer full): a new #ICalProperty holding TZNAME
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_tzname (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_tzname (value), NULL);
}

/**
 * i_cal_property_get_tzname:
 * @self: the #ICalProperty of TZNAME
 *
 * Returns value of the TZNAME @self
 *
 * Returns: the TZNAME value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_tzname (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_tzname ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_tzname:
 * @self: the #ICalProperty of TZNAME
 * @value: the TZNAME value
 *
 * Sets value to the TZNAME @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_tzname (ICalProperty *self, 
                           const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_tzname ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_tzoffsetfrom:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding TZOFFSETFROM.
 *
 * Returns: (transfer full): a new #ICalProperty holding TZOFFSETFROM
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_tzoffsetfrom (gint value)
{
	return i_cal_property_new_full (icalproperty_new_tzoffsetfrom (value), NULL);
}

/**
 * i_cal_property_get_tzoffsetfrom:
 * @self: the #ICalProperty of TZOFFSETFROM
 *
 * Returns value of the TZOFFSETFROM @self
 *
 * Returns: the TZOFFSETFROM value
 *
 * Since: 1.0
 *
 **/
gint
i_cal_property_get_tzoffsetfrom (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_tzoffsetfrom ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_tzoffsetfrom:
 * @self: the #ICalProperty of TZOFFSETFROM
 * @value: the TZOFFSETFROM value
 *
 * Sets value to the TZOFFSETFROM @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_tzoffsetfrom (ICalProperty *self, 
                                 gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_tzoffsetfrom ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_tzoffsetto:
 * @value: the integer value
 *
 * Creates a new #ICalProperty holding TZOFFSETTO.
 *
 * Returns: (transfer full): a new #ICalProperty holding TZOFFSETTO
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_tzoffsetto (gint value)
{
	return i_cal_property_new_full (icalproperty_new_tzoffsetto (value), NULL);
}

/**
 * i_cal_property_get_tzoffsetto:
 * @self: the #ICalProperty of TZOFFSETTO
 *
 * Returns value of the TZOFFSETTO @self
 *
 * Returns: the TZOFFSETTO value
 *
 * Since: 1.0
 *
 **/
gint
i_cal_property_get_tzoffsetto (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), 0);

	return icalproperty_get_tzoffsetto ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_tzoffsetto:
 * @self: the #ICalProperty of TZOFFSETTO
 * @value: the TZOFFSETTO value
 *
 * Sets value to the TZOFFSETTO @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_tzoffsetto (ICalProperty *self, 
                               gint value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_tzoffsetto ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_tzuntil:
 * @value: the #ICalTime value
 *
 * Creates a new #ICalProperty holding TZUNTIL.
 *
 * Returns: (transfer full): a new #ICalProperty holding TZUNTIL
 *
 * Since: 2.0
 *
 **/
ICalProperty *
i_cal_property_new_tzuntil (const ICalTime *value)
{
    g_return_val_if_fail (I_CAL_IS_TIME ((ICalTime*)value), NULL);

	return i_cal_property_new_full (icalproperty_new_tzuntil (* (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value))), NULL);
}

/**
 * i_cal_property_get_tzuntil:
 * @self: the #ICalProperty of TZUNTIL
 *
 * Returns value of the TZUNTIL @self
 *
 * Returns: (transfer full): the TZUNTIL value
 *
 * Since: 2.0
 *
 **/
ICalTime *
i_cal_property_get_tzuntil (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return i_cal_time_new_full (icalproperty_get_tzuntil ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_tzuntil:
 * @self: the #ICalProperty of TZUNTIL
 * @value: the TZUNTIL value
 *
 * Sets value to the TZUNTIL @self
 *
 * Since: 2.0
 *
 **/
void
i_cal_property_set_tzuntil (ICalProperty *self, 
                            const ICalTime *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (I_CAL_IS_TIME ((ICalTime*)value));

	icalproperty_set_tzuntil ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), * (struct icaltimetype *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)value)));
}

/**
 * i_cal_property_new_tzurl:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding TZURL.
 *
 * Returns: (transfer full): a new #ICalProperty holding TZURL
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_tzurl (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_tzurl (value), NULL);
}

/**
 * i_cal_property_get_tzurl:
 * @self: the #ICalProperty of TZURL
 *
 * Returns value of the TZURL @self
 *
 * Returns: the TZURL value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_tzurl (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_tzurl ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_tzurl:
 * @self: the #ICalProperty of TZURL
 * @value: the TZURL value
 *
 * Sets value to the TZURL @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_tzurl (ICalProperty *self, 
                          const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_tzurl ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_uid:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding UID.
 *
 * Returns: (transfer full): a new #ICalProperty holding UID
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_uid (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_uid (value), NULL);
}

/**
 * i_cal_property_get_uid:
 * @self: the #ICalProperty of UID
 *
 * Returns value of the UID @self
 *
 * Returns: the UID value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_uid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_uid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_uid:
 * @self: the #ICalProperty of UID
 * @value: the UID value
 *
 * Sets value to the UID @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_uid (ICalProperty *self, 
                        const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_uid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_url:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding URL.
 *
 * Returns: (transfer full): a new #ICalProperty holding URL
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_url (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_url (value), NULL);
}

/**
 * i_cal_property_get_url:
 * @self: the #ICalProperty of URL
 *
 * Returns value of the URL @self
 *
 * Returns: the URL value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_url (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_url ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_url:
 * @self: the #ICalProperty of URL
 * @value: the URL value
 *
 * Sets value to the URL @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_url (ICalProperty *self, 
                        const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_url ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_version:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding VERSION.
 *
 * Returns: (transfer full): a new #ICalProperty holding VERSION
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_version (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_version (value), NULL);
}

/**
 * i_cal_property_get_version:
 * @self: the #ICalProperty of VERSION
 *
 * Returns value of the VERSION @self
 *
 * Returns: the VERSION value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_version (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_version ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_version:
 * @self: the #ICalProperty of VERSION
 * @value: the VERSION value
 *
 * Sets value to the VERSION @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_version (ICalProperty *self, 
                            const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_version ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_voter:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding VOTER.
 *
 * Returns: (transfer full): a new #ICalProperty holding VOTER
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_voter (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_voter (value), NULL);
}

/**
 * i_cal_property_get_voter:
 * @self: the #ICalProperty of VOTER
 *
 * Returns value of the VOTER @self
 *
 * Returns: the VOTER value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_voter (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_voter ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_voter:
 * @self: the #ICalProperty of VOTER
 * @value: the VOTER value
 *
 * Sets value to the VOTER @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_voter (ICalProperty *self, 
                          const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_voter ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_x:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding X.
 *
 * Returns: (transfer full): a new #ICalProperty holding X
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_x (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_x (value), NULL);
}

/**
 * i_cal_property_get_x:
 * @self: the #ICalProperty of X
 *
 * Returns value of the X @self
 *
 * Returns: the X value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_x (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_x ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_x:
 * @self: the #ICalProperty of X
 * @value: the X value
 *
 * Sets value to the X @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_x (ICalProperty *self, 
                      const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_x ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_xlicclass:
 * @value: the #ICalPropertyXlicclass value
 *
 * Creates a new #ICalProperty holding XLICCLASS.
 *
 * Returns: (transfer full): a new #ICalProperty holding XLICCLASS
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_xlicclass (ICalPropertyXlicclass value)
{
	return i_cal_property_new_full (icalproperty_new_xlicclass ((icalproperty_xlicclass) (value)), NULL);
}

/**
 * i_cal_property_get_xlicclass:
 * @self: the #ICalProperty of XLICCLASS
 *
 * Returns value of the XLICCLASS @self
 *
 * Returns: the XLICCLASS value
 *
 * Since: 1.0
 *
 **/
ICalPropertyXlicclass
i_cal_property_get_xlicclass (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), I_CAL_XLICCLASS_NONE);

	return (ICalPropertyXlicclass) (icalproperty_get_xlicclass ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self))));
}

/**
 * i_cal_property_set_xlicclass:
 * @self: the #ICalProperty of XLICCLASS
 * @value: the XLICCLASS value
 *
 * Sets value to the XLICCLASS @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_xlicclass (ICalProperty *self, 
                              ICalPropertyXlicclass value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));

	icalproperty_set_xlicclass ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), (icalproperty_xlicclass) (value));
}

/**
 * i_cal_property_new_xlicclustercount:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding XLICCLUSTERCOUNT.
 *
 * Returns: (transfer full): a new #ICalProperty holding XLICCLUSTERCOUNT
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_xlicclustercount (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_xlicclustercount (value), NULL);
}

/**
 * i_cal_property_get_xlicclustercount:
 * @self: the #ICalProperty of XLICCLUSTERCOUNT
 *
 * Returns value of the XLICCLUSTERCOUNT @self
 *
 * Returns: the XLICCLUSTERCOUNT value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_xlicclustercount (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_xlicclustercount ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_xlicclustercount:
 * @self: the #ICalProperty of XLICCLUSTERCOUNT
 * @value: the XLICCLUSTERCOUNT value
 *
 * Sets value to the XLICCLUSTERCOUNT @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_xlicclustercount (ICalProperty *self, 
                                     const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_xlicclustercount ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_xlicerror:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding XLICERROR.
 *
 * Returns: (transfer full): a new #ICalProperty holding XLICERROR
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_xlicerror (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_xlicerror (value), NULL);
}

/**
 * i_cal_property_get_xlicerror:
 * @self: the #ICalProperty of XLICERROR
 *
 * Returns value of the XLICERROR @self
 *
 * Returns: the XLICERROR value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_xlicerror (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_xlicerror ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_xlicerror:
 * @self: the #ICalProperty of XLICERROR
 * @value: the XLICERROR value
 *
 * Sets value to the XLICERROR @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_xlicerror (ICalProperty *self, 
                              const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_xlicerror ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_xlicmimecharset:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding XLICMIMECHARSET.
 *
 * Returns: (transfer full): a new #ICalProperty holding XLICMIMECHARSET
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_xlicmimecharset (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_xlicmimecharset (value), NULL);
}

/**
 * i_cal_property_get_xlicmimecharset:
 * @self: the #ICalProperty of XLICMIMECHARSET
 *
 * Returns value of the XLICMIMECHARSET @self
 *
 * Returns: the XLICMIMECHARSET value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_xlicmimecharset (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_xlicmimecharset ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_xlicmimecharset:
 * @self: the #ICalProperty of XLICMIMECHARSET
 * @value: the XLICMIMECHARSET value
 *
 * Sets value to the XLICMIMECHARSET @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_xlicmimecharset (ICalProperty *self, 
                                    const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_xlicmimecharset ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_xlicmimecid:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding XLICMIMECID.
 *
 * Returns: (transfer full): a new #ICalProperty holding XLICMIMECID
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_xlicmimecid (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_xlicmimecid (value), NULL);
}

/**
 * i_cal_property_get_xlicmimecid:
 * @self: the #ICalProperty of XLICMIMECID
 *
 * Returns value of the XLICMIMECID @self
 *
 * Returns: the XLICMIMECID value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_xlicmimecid (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_xlicmimecid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_xlicmimecid:
 * @self: the #ICalProperty of XLICMIMECID
 * @value: the XLICMIMECID value
 *
 * Sets value to the XLICMIMECID @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_xlicmimecid (ICalProperty *self, 
                                const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_xlicmimecid ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_xlicmimecontenttype:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding XLICMIMECONTENTTYPE.
 *
 * Returns: (transfer full): a new #ICalProperty holding XLICMIMECONTENTTYPE
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_xlicmimecontenttype (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_xlicmimecontenttype (value), NULL);
}

/**
 * i_cal_property_get_xlicmimecontenttype:
 * @self: the #ICalProperty of XLICMIMECONTENTTYPE
 *
 * Returns value of the XLICMIMECONTENTTYPE @self
 *
 * Returns: the XLICMIMECONTENTTYPE value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_xlicmimecontenttype (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_xlicmimecontenttype ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_xlicmimecontenttype:
 * @self: the #ICalProperty of XLICMIMECONTENTTYPE
 * @value: the XLICMIMECONTENTTYPE value
 *
 * Sets value to the XLICMIMECONTENTTYPE @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_xlicmimecontenttype (ICalProperty *self, 
                                        const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_xlicmimecontenttype ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_xlicmimeencoding:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding XLICMIMEENCODING.
 *
 * Returns: (transfer full): a new #ICalProperty holding XLICMIMEENCODING
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_xlicmimeencoding (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_xlicmimeencoding (value), NULL);
}

/**
 * i_cal_property_get_xlicmimeencoding:
 * @self: the #ICalProperty of XLICMIMEENCODING
 *
 * Returns value of the XLICMIMEENCODING @self
 *
 * Returns: the XLICMIMEENCODING value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_xlicmimeencoding (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_xlicmimeencoding ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_xlicmimeencoding:
 * @self: the #ICalProperty of XLICMIMEENCODING
 * @value: the XLICMIMEENCODING value
 *
 * Sets value to the XLICMIMEENCODING @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_xlicmimeencoding (ICalProperty *self, 
                                     const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_xlicmimeencoding ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_xlicmimefilename:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding XLICMIMEFILENAME.
 *
 * Returns: (transfer full): a new #ICalProperty holding XLICMIMEFILENAME
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_xlicmimefilename (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_xlicmimefilename (value), NULL);
}

/**
 * i_cal_property_get_xlicmimefilename:
 * @self: the #ICalProperty of XLICMIMEFILENAME
 *
 * Returns value of the XLICMIMEFILENAME @self
 *
 * Returns: the XLICMIMEFILENAME value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_xlicmimefilename (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_xlicmimefilename ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_xlicmimefilename:
 * @self: the #ICalProperty of XLICMIMEFILENAME
 * @value: the XLICMIMEFILENAME value
 *
 * Sets value to the XLICMIMEFILENAME @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_xlicmimefilename (ICalProperty *self, 
                                     const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_xlicmimefilename ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}

/**
 * i_cal_property_new_xlicmimeoptinfo:
 * @value: the text value
 *
 * Creates a new #ICalProperty holding XLICMIMEOPTINFO.
 *
 * Returns: (transfer full): a new #ICalProperty holding XLICMIMEOPTINFO
 *
 * Since: 1.0
 *
 **/
ICalProperty *
i_cal_property_new_xlicmimeoptinfo (const gchar *value)
{
    g_return_val_if_fail (value != NULL, NULL);

	return i_cal_property_new_full (icalproperty_new_xlicmimeoptinfo (value), NULL);
}

/**
 * i_cal_property_get_xlicmimeoptinfo:
 * @self: the #ICalProperty of XLICMIMEOPTINFO
 *
 * Returns value of the XLICMIMEOPTINFO @self
 *
 * Returns: the XLICMIMEOPTINFO value
 *
 * Since: 1.0
 *
 **/
const gchar *
i_cal_property_get_xlicmimeoptinfo (const ICalProperty *self)
{
    g_return_val_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self), NULL);

	return icalproperty_get_xlicmimeoptinfo ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)));
}

/**
 * i_cal_property_set_xlicmimeoptinfo:
 * @self: the #ICalProperty of XLICMIMEOPTINFO
 * @value: the XLICMIMEOPTINFO value
 *
 * Sets value to the XLICMIMEOPTINFO @self
 *
 * Since: 1.0
 *
 **/
void
i_cal_property_set_xlicmimeoptinfo (ICalProperty *self, 
                                    const gchar *value)
{
    g_return_if_fail (I_CAL_IS_PROPERTY ((ICalProperty*)self));
    g_return_if_fail (value != NULL);

	icalproperty_set_xlicmimeoptinfo ((icalproperty *)i_cal_object_get_native (I_CAL_OBJECT ((ICalObject *)self)), value);
}
